package androidx.core.content.res;

import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Color;
import android.os.Build;
import android.util.AttributeSet;
import android.util.Log;
import android.util.StateSet;
import android.util.TypedValue;
import android.util.Xml;
import androidx.annotation.ColorInt;
import androidx.annotation.ColorRes;
import androidx.annotation.FloatRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RestrictTo;
import androidx.annotation.XmlRes;
import androidx.core.R;
import androidx.core.math.MathUtils;
import androidx.core.view.ViewCompat;
import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
public final class ColorStateListInflaterCompat {
    private static final ThreadLocal<TypedValue> sTempTypedValue = new ThreadLocal<>();

    private ColorStateListInflaterCompat() {
    }

    @NonNull
    public static ColorStateList createFromXml(@NonNull Resources resources, @NonNull XmlPullParser xmlPullParser, @Nullable Resources.Theme theme) throws XmlPullParserException, IOException {
        int next;
        AttributeSet asAttributeSet = Xml.asAttributeSet(xmlPullParser);
        do {
            next = xmlPullParser.next();
            if (next == 2) {
                break;
            }
        } while (next != 1);
        if (next == 2) {
            return createFromXmlInner(resources, xmlPullParser, asAttributeSet, theme);
        }
        throw new XmlPullParserException("No start tag found");
    }

    @NonNull
    public static ColorStateList createFromXmlInner(@NonNull Resources resources, @NonNull XmlPullParser xmlPullParser, @NonNull AttributeSet attributeSet, @Nullable Resources.Theme theme) throws XmlPullParserException, IOException {
        String name = xmlPullParser.getName();
        if (name.equals("selector")) {
            return inflate(resources, xmlPullParser, attributeSet, theme);
        }
        throw new XmlPullParserException(xmlPullParser.getPositionDescription() + ": invalid color state list tag " + name);
    }

    @NonNull
    private static TypedValue getTypedValue() {
        ThreadLocal<TypedValue> threadLocal = sTempTypedValue;
        TypedValue typedValue = threadLocal.get();
        if (typedValue != null) {
            return typedValue;
        }
        TypedValue typedValue2 = new TypedValue();
        threadLocal.set(typedValue2);
        return typedValue2;
    }

    @Nullable
    public static ColorStateList inflate(@NonNull Resources resources, @XmlRes int i7, @Nullable Resources.Theme theme) {
        try {
            return createFromXml(resources, resources.getXml(i7), theme);
        } catch (Exception e7) {
            Log.e("CSLCompat", "Failed to inflate ColorStateList.", e7);
            return null;
        }
    }

    private static boolean isColorInt(@NonNull Resources resources, @ColorRes int i7) {
        TypedValue typedValue = getTypedValue();
        resources.getValue(i7, typedValue, true);
        int i8 = typedValue.type;
        return i8 >= 28 && i8 <= 31;
    }

    @ColorInt
    private static int modulateColorAlpha(@ColorInt int i7, @FloatRange(from = 0.0d, to = 1.0d) float f7, @FloatRange(from = 0.0d, to = 100.0d) float f8) {
        boolean z7 = f8 >= 0.0f && f8 <= 100.0f;
        if (f7 == 1.0f && !z7) {
            return i7;
        }
        int clamp = MathUtils.clamp((int) ((((float) Color.alpha(i7)) * f7) + 0.5f), 0, 255);
        if (z7) {
            CamColor fromColor = CamColor.fromColor(i7);
            i7 = CamColor.toColor(fromColor.getHue(), fromColor.getChroma(), f8);
        }
        return (i7 & ViewCompat.MEASURED_SIZE_MASK) | (clamp << 24);
    }

    private static TypedArray obtainAttributes(Resources resources, Resources.Theme theme, AttributeSet attributeSet, int[] iArr) {
        return theme == null ? resources.obtainAttributes(attributeSet, iArr) : theme.obtainStyledAttributes(attributeSet, iArr, 0, 0);
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x006a  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0071  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0084  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00a2  */
    private static ColorStateList inflate(@NonNull Resources resources, @NonNull XmlPullParser xmlPullParser, @NonNull AttributeSet attributeSet, @Nullable Resources.Theme theme) throws XmlPullParserException, IOException {
        int depth;
        int i7;
        int attributeCount;
        int i8;
        int i9;
        Resources resources2 = resources;
        int i10 = 1;
        int depth2 = xmlPullParser.getDepth() + 1;
        int[][] iArr = new int[20][];
        int[] iArr2 = new int[20];
        int i11 = 0;
        while (true) {
            int next = xmlPullParser.next();
            if (next == i10 || ((depth = xmlPullParser.getDepth()) < depth2 && next == 3)) {
                int[] iArr3 = new int[i11];
                int[][] iArr4 = new int[i11][];
                System.arraycopy(iArr2, 0, iArr3, 0, i11);
                System.arraycopy(iArr, 0, iArr4, 0, i11);
            } else {
                if (next == 2 && depth <= depth2 && xmlPullParser.getName().equals("item")) {
                    TypedArray obtainAttributes = obtainAttributes(resources2, theme, attributeSet, R.styleable.ColorStateListItem);
                    int resourceId = obtainAttributes.getResourceId(R.styleable.ColorStateListItem_android_color, -1);
                    if (resourceId != -1 && !isColorInt(resources2, resourceId)) {
                        try {
                            i7 = createFromXml(resources2, resources2.getXml(resourceId), theme).getDefaultColor();
                        } catch (Exception unused) {
                        }
                        float f7 = 1.0f;
                        if (!obtainAttributes.hasValue(R.styleable.ColorStateListItem_android_alpha)) {
                            i9 = R.styleable.ColorStateListItem_android_alpha;
                        } else {
                            if (obtainAttributes.hasValue(R.styleable.ColorStateListItem_alpha)) {
                                i9 = R.styleable.ColorStateListItem_alpha;
                            }
                            float f8 = obtainAttributes.getFloat((Build.VERSION.SDK_INT >= 31 || !obtainAttributes.hasValue(R.styleable.ColorStateListItem_android_lStar)) ? R.styleable.ColorStateListItem_lStar : R.styleable.ColorStateListItem_android_lStar, -1.0f);
                            obtainAttributes.recycle();
                            attributeCount = attributeSet.getAttributeCount();
                            int[] iArr5 = new int[attributeCount];
                            int i12 = 0;
                            for (i8 = 0; i8 < attributeCount; i8++) {
                                int attributeNameResource = attributeSet.getAttributeNameResource(i8);
                                if (!(attributeNameResource == 16843173 || attributeNameResource == 16843551 || attributeNameResource == R.attr.alpha || attributeNameResource == R.attr.lStar)) {
                                    int i13 = i12 + 1;
                                    if (!attributeSet.getAttributeBooleanValue(i8, false)) {
                                        attributeNameResource = -attributeNameResource;
                                    }
                                    iArr5[i12] = attributeNameResource;
                                    i12 = i13;
                                }
                            }
                            int[] trimStateSet = StateSet.trimStateSet(iArr5, i12);
                            iArr2 = GrowingArrayUtils.append(iArr2, i11, modulateColorAlpha(i7, f7, f8));
                            iArr = (int[][]) GrowingArrayUtils.append(iArr, i11, trimStateSet);
                            i11++;
                        }
                        f7 = obtainAttributes.getFloat(i9, 1.0f);
                        float f82 = obtainAttributes.getFloat((Build.VERSION.SDK_INT >= 31 || !obtainAttributes.hasValue(R.styleable.ColorStateListItem_android_lStar)) ? R.styleable.ColorStateListItem_lStar : R.styleable.ColorStateListItem_android_lStar, -1.0f);
                        obtainAttributes.recycle();
                        attributeCount = attributeSet.getAttributeCount();
                        int[] iArr52 = new int[attributeCount];
                        int i122 = 0;
                        while (i8 < attributeCount) {
                        }
                        int[] trimStateSet2 = StateSet.trimStateSet(iArr52, i122);
                        iArr2 = GrowingArrayUtils.append(iArr2, i11, modulateColorAlpha(i7, f7, f82));
                        iArr = (int[][]) GrowingArrayUtils.append(iArr, i11, trimStateSet2);
                        i11++;
                    }
                    i7 = obtainAttributes.getColor(R.styleable.ColorStateListItem_android_color, -65281);
                    float f72 = 1.0f;
                    if (!obtainAttributes.hasValue(R.styleable.ColorStateListItem_android_alpha)) {
                    }
                    f72 = obtainAttributes.getFloat(i9, 1.0f);
                    float f822 = obtainAttributes.getFloat((Build.VERSION.SDK_INT >= 31 || !obtainAttributes.hasValue(R.styleable.ColorStateListItem_android_lStar)) ? R.styleable.ColorStateListItem_lStar : R.styleable.ColorStateListItem_android_lStar, -1.0f);
                    obtainAttributes.recycle();
                    attributeCount = attributeSet.getAttributeCount();
                    int[] iArr522 = new int[attributeCount];
                    int i1222 = 0;
                    while (i8 < attributeCount) {
                    }
                    int[] trimStateSet22 = StateSet.trimStateSet(iArr522, i1222);
                    iArr2 = GrowingArrayUtils.append(iArr2, i11, modulateColorAlpha(i7, f72, f822));
                    iArr = (int[][]) GrowingArrayUtils.append(iArr, i11, trimStateSet22);
                    i11++;
                }
                i10 = 1;
                resources2 = resources;
            }
        }
        int[] iArr32 = new int[i11];
        int[][] iArr42 = new int[i11][];
        System.arraycopy(iArr2, 0, iArr32, 0, i11);
        System.arraycopy(iArr, 0, iArr42, 0, i11);
        return new ColorStateList(iArr42, iArr32);
    }
}
