package androidx.core.graphics;

import android.graphics.Color;
import androidx.annotation.ColorInt;
import androidx.annotation.DoNotInline;
import androidx.annotation.FloatRange;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.annotation.VisibleForTesting;
import androidx.core.view.ViewCompat;
import java.util.Objects;

public final class ColorUtils {
    private static final int MIN_ALPHA_SEARCH_MAX_ITERATIONS = 10;
    private static final int MIN_ALPHA_SEARCH_PRECISION = 1;
    private static final ThreadLocal<double[]> TEMP_ARRAY = new ThreadLocal<>();
    private static final double XYZ_EPSILON = 0.008856d;
    private static final double XYZ_KAPPA = 903.3d;
    private static final double XYZ_WHITE_REFERENCE_X = 95.047d;
    private static final double XYZ_WHITE_REFERENCE_Y = 100.0d;
    private static final double XYZ_WHITE_REFERENCE_Z = 108.883d;

    @RequiresApi(26)
    static class Api26Impl {
        private Api26Impl() {
        }

        @DoNotInline
        static Color compositeColors(Color color, Color color2) {
            if (Objects.equals(color.getModel(), color2.getModel())) {
                if (!Objects.equals(color2.getColorSpace(), color.getColorSpace())) {
                    color = color.convert(color2.getColorSpace());
                }
                float[] components = color.getComponents();
                float[] components2 = color2.getComponents();
                float alpha = color.alpha();
                float alpha2 = color2.alpha() * (1.0f - alpha);
                int componentCount = color2.getComponentCount() - 1;
                float f7 = alpha + alpha2;
                components2[componentCount] = f7;
                if (f7 > 0.0f) {
                    alpha /= f7;
                    alpha2 /= f7;
                }
                for (int i7 = 0; i7 < componentCount; i7++) {
                    components2[i7] = (components[i7] * alpha) + (components2[i7] * alpha2);
                }
                return Color.valueOf(components2, color2.getColorSpace());
            }
            throw new IllegalArgumentException("Color models must match (" + color.getModel() + " vs. " + color2.getModel() + ")");
        }
    }

    private ColorUtils() {
    }

    @ColorInt
    public static int HSLToColor(@NonNull float[] fArr) {
        int i7;
        int i8;
        int i9;
        float f7 = fArr[0];
        float f8 = fArr[1];
        float f9 = fArr[2];
        float abs = (1.0f - Math.abs((f9 * 2.0f) - 1.0f)) * f8;
        float f10 = f9 - (0.5f * abs);
        float abs2 = (1.0f - Math.abs(((f7 / 60.0f) % 2.0f) - 1.0f)) * abs;
        switch (((int) f7) / 60) {
            case 0:
                i9 = Math.round((abs + f10) * 255.0f);
                i8 = Math.round((abs2 + f10) * 255.0f);
                i7 = Math.round(f10 * 255.0f);
                break;
            case 1:
                i9 = Math.round((abs2 + f10) * 255.0f);
                i8 = Math.round((abs + f10) * 255.0f);
                i7 = Math.round(f10 * 255.0f);
                break;
            case 2:
                i9 = Math.round(f10 * 255.0f);
                i8 = Math.round((abs + f10) * 255.0f);
                i7 = Math.round((abs2 + f10) * 255.0f);
                break;
            case 3:
                i9 = Math.round(f10 * 255.0f);
                i8 = Math.round((abs2 + f10) * 255.0f);
                i7 = Math.round((abs + f10) * 255.0f);
                break;
            case 4:
                i9 = Math.round((abs2 + f10) * 255.0f);
                i8 = Math.round(f10 * 255.0f);
                i7 = Math.round((abs + f10) * 255.0f);
                break;
            case 5:
            case 6:
                i9 = Math.round((abs + f10) * 255.0f);
                i8 = Math.round(f10 * 255.0f);
                i7 = Math.round((abs2 + f10) * 255.0f);
                break;
            default:
                i7 = 0;
                i9 = 0;
                i8 = 0;
                break;
        }
        return Color.rgb(constrain(i9, 0, 255), constrain(i8, 0, 255), constrain(i7, 0, 255));
    }

    @ColorInt
    public static int LABToColor(@FloatRange(from = 0.0d, to = 100.0d) double d7, @FloatRange(from = -128.0d, to = 127.0d) double d8, @FloatRange(from = -128.0d, to = 127.0d) double d9) {
        double[] tempDouble3Array = getTempDouble3Array();
        LABToXYZ(d7, d8, d9, tempDouble3Array);
        return XYZToColor(tempDouble3Array[0], tempDouble3Array[1], tempDouble3Array[2]);
    }

    public static void LABToXYZ(@FloatRange(from = 0.0d, to = 100.0d) double d7, @FloatRange(from = -128.0d, to = 127.0d) double d8, @FloatRange(from = -128.0d, to = 127.0d) double d9, @NonNull double[] dArr) {
        double d10 = (d7 + 16.0d) / 116.0d;
        double d11 = (d8 / 500.0d) + d10;
        double d12 = d10 - (d9 / 200.0d);
        double pow = Math.pow(d11, 3.0d);
        if (pow <= XYZ_EPSILON) {
            pow = ((d11 * 116.0d) - 16.0d) / XYZ_KAPPA;
        }
        double pow2 = d7 > 7.9996247999999985d ? Math.pow(d10, 3.0d) : d7 / XYZ_KAPPA;
        double pow3 = Math.pow(d12, 3.0d);
        if (pow3 <= XYZ_EPSILON) {
            pow3 = ((d12 * 116.0d) - 16.0d) / XYZ_KAPPA;
        }
        dArr[0] = pow * XYZ_WHITE_REFERENCE_X;
        dArr[1] = pow2 * XYZ_WHITE_REFERENCE_Y;
        dArr[2] = pow3 * XYZ_WHITE_REFERENCE_Z;
    }

    public static void RGBToHSL(@IntRange(from = 0, to = 255) int i7, @IntRange(from = 0, to = 255) int i8, @IntRange(from = 0, to = 255) int i9, @NonNull float[] fArr) {
        float f7;
        float f8;
        float f9 = ((float) i7) / 255.0f;
        float f10 = ((float) i8) / 255.0f;
        float f11 = ((float) i9) / 255.0f;
        float max = Math.max(f9, Math.max(f10, f11));
        float min = Math.min(f9, Math.min(f10, f11));
        float f12 = max - min;
        float f13 = (max + min) / 2.0f;
        if (max == min) {
            f7 = 0.0f;
            f8 = 0.0f;
        } else {
            f7 = max == f9 ? ((f10 - f11) / f12) % 6.0f : max == f10 ? ((f11 - f9) / f12) + 2.0f : 4.0f + ((f9 - f10) / f12);
            f8 = f12 / (1.0f - Math.abs((2.0f * f13) - 1.0f));
        }
        float f14 = (f7 * 60.0f) % 360.0f;
        if (f14 < 0.0f) {
            f14 += 360.0f;
        }
        fArr[0] = constrain(f14, 0.0f, 360.0f);
        fArr[1] = constrain(f8, 0.0f, 1.0f);
        fArr[2] = constrain(f13, 0.0f, 1.0f);
    }

    public static void RGBToLAB(@IntRange(from = 0, to = 255) int i7, @IntRange(from = 0, to = 255) int i8, @IntRange(from = 0, to = 255) int i9, @NonNull double[] dArr) {
        RGBToXYZ(i7, i8, i9, dArr);
        XYZToLAB(dArr[0], dArr[1], dArr[2], dArr);
    }

    public static void RGBToXYZ(@IntRange(from = 0, to = 255) int i7, @IntRange(from = 0, to = 255) int i8, @IntRange(from = 0, to = 255) int i9, @NonNull double[] dArr) {
        if (dArr.length == 3) {
            double d7 = ((double) i7) / 255.0d;
            double pow = d7 < 0.04045d ? d7 / 12.92d : Math.pow((d7 + 0.055d) / 1.055d, 2.4d);
            double d8 = ((double) i8) / 255.0d;
            double pow2 = d8 < 0.04045d ? d8 / 12.92d : Math.pow((d8 + 0.055d) / 1.055d, 2.4d);
            double d9 = ((double) i9) / 255.0d;
            double pow3 = d9 < 0.04045d ? d9 / 12.92d : Math.pow((d9 + 0.055d) / 1.055d, 2.4d);
            dArr[0] = ((0.4124d * pow) + (0.3576d * pow2) + (0.1805d * pow3)) * XYZ_WHITE_REFERENCE_Y;
            dArr[1] = ((0.2126d * pow) + (0.7152d * pow2) + (0.0722d * pow3)) * XYZ_WHITE_REFERENCE_Y;
            dArr[2] = ((pow * 0.0193d) + (pow2 * 0.1192d) + (pow3 * 0.9505d)) * XYZ_WHITE_REFERENCE_Y;
            return;
        }
        throw new IllegalArgumentException("outXyz must have a length of 3.");
    }

    @ColorInt
    public static int XYZToColor(@FloatRange(from = 0.0d, to = 95.047d) double d7, @FloatRange(from = 0.0d, to = 100.0d) double d8, @FloatRange(from = 0.0d, to = 108.883d) double d9) {
        double d10 = (((3.2406d * d7) + (-1.5372d * d8)) + (-0.4986d * d9)) / XYZ_WHITE_REFERENCE_Y;
        double d11 = (((-0.9689d * d7) + (1.8758d * d8)) + (0.0415d * d9)) / XYZ_WHITE_REFERENCE_Y;
        double d12 = (((0.0557d * d7) + (-0.204d * d8)) + (1.057d * d9)) / XYZ_WHITE_REFERENCE_Y;
        return Color.rgb(constrain((int) Math.round((d10 > 0.0031308d ? (Math.pow(d10, 0.4166666666666667d) * 1.055d) - 0.055d : d10 * 12.92d) * 255.0d), 0, 255), constrain((int) Math.round((d11 > 0.0031308d ? (Math.pow(d11, 0.4166666666666667d) * 1.055d) - 0.055d : d11 * 12.92d) * 255.0d), 0, 255), constrain((int) Math.round((d12 > 0.0031308d ? (Math.pow(d12, 0.4166666666666667d) * 1.055d) - 0.055d : d12 * 12.92d) * 255.0d), 0, 255));
    }

    public static void XYZToLAB(@FloatRange(from = 0.0d, to = 95.047d) double d7, @FloatRange(from = 0.0d, to = 100.0d) double d8, @FloatRange(from = 0.0d, to = 108.883d) double d9, @NonNull double[] dArr) {
        if (dArr.length == 3) {
            double pivotXyzComponent = pivotXyzComponent(d7 / XYZ_WHITE_REFERENCE_X);
            double pivotXyzComponent2 = pivotXyzComponent(d8 / XYZ_WHITE_REFERENCE_Y);
            double pivotXyzComponent3 = pivotXyzComponent(d9 / XYZ_WHITE_REFERENCE_Z);
            dArr[0] = Math.max(0.0d, (116.0d * pivotXyzComponent2) - 16.0d);
            dArr[1] = (pivotXyzComponent - pivotXyzComponent2) * 500.0d;
            dArr[2] = (pivotXyzComponent2 - pivotXyzComponent3) * 200.0d;
            return;
        }
        throw new IllegalArgumentException("outLab must have a length of 3.");
    }

    @ColorInt
    public static int blendARGB(@ColorInt int i7, @ColorInt int i8, @FloatRange(from = 0.0d, to = 1.0d) float f7) {
        float f8 = 1.0f - f7;
        return Color.argb((int) ((((float) Color.alpha(i7)) * f8) + (((float) Color.alpha(i8)) * f7)), (int) ((((float) Color.red(i7)) * f8) + (((float) Color.red(i8)) * f7)), (int) ((((float) Color.green(i7)) * f8) + (((float) Color.green(i8)) * f7)), (int) ((((float) Color.blue(i7)) * f8) + (((float) Color.blue(i8)) * f7)));
    }

    public static void blendHSL(@NonNull float[] fArr, @NonNull float[] fArr2, @FloatRange(from = 0.0d, to = 1.0d) float f7, @NonNull float[] fArr3) {
        if (fArr3.length == 3) {
            float f8 = 1.0f - f7;
            fArr3[0] = circularInterpolate(fArr[0], fArr2[0], f7);
            fArr3[1] = (fArr[1] * f8) + (fArr2[1] * f7);
            fArr3[2] = (fArr[2] * f8) + (fArr2[2] * f7);
            return;
        }
        throw new IllegalArgumentException("result must have a length of 3.");
    }

    public static void blendLAB(@NonNull double[] dArr, @NonNull double[] dArr2, @FloatRange(from = 0.0d, to = 1.0d) double d7, @NonNull double[] dArr3) {
        if (dArr3.length == 3) {
            double d8 = 1.0d - d7;
            dArr3[0] = (dArr[0] * d8) + (dArr2[0] * d7);
            dArr3[1] = (dArr[1] * d8) + (dArr2[1] * d7);
            dArr3[2] = (dArr[2] * d8) + (dArr2[2] * d7);
            return;
        }
        throw new IllegalArgumentException("outResult must have a length of 3.");
    }

    public static double calculateContrast(@ColorInt int i7, @ColorInt int i8) {
        if (Color.alpha(i8) == 255) {
            if (Color.alpha(i7) < 255) {
                i7 = compositeColors(i7, i8);
            }
            double calculateLuminance = calculateLuminance(i7) + 0.05d;
            double calculateLuminance2 = calculateLuminance(i8) + 0.05d;
            return Math.max(calculateLuminance, calculateLuminance2) / Math.min(calculateLuminance, calculateLuminance2);
        }
        throw new IllegalArgumentException("background can not be translucent: #" + Integer.toHexString(i8));
    }

    @FloatRange(from = 0.0d, to = 1.0d)
    public static double calculateLuminance(@ColorInt int i7) {
        double[] tempDouble3Array = getTempDouble3Array();
        colorToXYZ(i7, tempDouble3Array);
        return tempDouble3Array[1] / XYZ_WHITE_REFERENCE_Y;
    }

    public static int calculateMinimumAlpha(@ColorInt int i7, @ColorInt int i8, float f7) {
        int i9 = 255;
        if (Color.alpha(i8) == 255) {
            double d7 = (double) f7;
            if (calculateContrast(setAlphaComponent(i7, 255), i8) < d7) {
                return -1;
            }
            int i10 = 0;
            for (int i11 = 0; i11 <= 10 && i9 - i10 > 1; i11++) {
                int i12 = (i10 + i9) / 2;
                if (calculateContrast(setAlphaComponent(i7, i12), i8) < d7) {
                    i10 = i12;
                } else {
                    i9 = i12;
                }
            }
            return i9;
        }
        throw new IllegalArgumentException("background can not be translucent: #" + Integer.toHexString(i8));
    }

    @VisibleForTesting
    static float circularInterpolate(float f7, float f8, float f9) {
        if (Math.abs(f8 - f7) > 180.0f) {
            if (f8 > f7) {
                f7 += 360.0f;
            } else {
                f8 += 360.0f;
            }
        }
        return (f7 + ((f8 - f7) * f9)) % 360.0f;
    }

    public static void colorToHSL(@ColorInt int i7, @NonNull float[] fArr) {
        RGBToHSL(Color.red(i7), Color.green(i7), Color.blue(i7), fArr);
    }

    public static void colorToLAB(@ColorInt int i7, @NonNull double[] dArr) {
        RGBToLAB(Color.red(i7), Color.green(i7), Color.blue(i7), dArr);
    }

    public static void colorToXYZ(@ColorInt int i7, @NonNull double[] dArr) {
        RGBToXYZ(Color.red(i7), Color.green(i7), Color.blue(i7), dArr);
    }

    private static int compositeAlpha(int i7, int i8) {
        return 255 - (((255 - i8) * (255 - i7)) / 255);
    }

    public static int compositeColors(@ColorInt int i7, @ColorInt int i8) {
        int alpha = Color.alpha(i8);
        int alpha2 = Color.alpha(i7);
        int compositeAlpha = compositeAlpha(alpha2, alpha);
        return Color.argb(compositeAlpha, compositeComponent(Color.red(i7), alpha2, Color.red(i8), alpha, compositeAlpha), compositeComponent(Color.green(i7), alpha2, Color.green(i8), alpha, compositeAlpha), compositeComponent(Color.blue(i7), alpha2, Color.blue(i8), alpha, compositeAlpha));
    }

    private static int compositeComponent(int i7, int i8, int i9, int i10, int i11) {
        if (i11 == 0) {
            return 0;
        }
        return (((i7 * 255) * i8) + ((i9 * i10) * (255 - i8))) / (i11 * 255);
    }

    private static float constrain(float f7, float f8, float f9) {
        return f7 < f8 ? f8 : Math.min(f7, f9);
    }

    public static double distanceEuclidean(@NonNull double[] dArr, @NonNull double[] dArr2) {
        return Math.sqrt(Math.pow(dArr[0] - dArr2[0], 2.0d) + Math.pow(dArr[1] - dArr2[1], 2.0d) + Math.pow(dArr[2] - dArr2[2], 2.0d));
    }

    private static double[] getTempDouble3Array() {
        ThreadLocal<double[]> threadLocal = TEMP_ARRAY;
        double[] dArr = threadLocal.get();
        if (dArr != null) {
            return dArr;
        }
        double[] dArr2 = new double[3];
        threadLocal.set(dArr2);
        return dArr2;
    }

    private static double pivotXyzComponent(double d7) {
        return d7 > XYZ_EPSILON ? Math.pow(d7, 0.3333333333333333d) : ((d7 * XYZ_KAPPA) + 16.0d) / 116.0d;
    }

    @ColorInt
    public static int setAlphaComponent(@ColorInt int i7, @IntRange(from = 0, to = 255) int i8) {
        if (i8 >= 0 && i8 <= 255) {
            return (i7 & ViewCompat.MEASURED_SIZE_MASK) | (i8 << 24);
        }
        throw new IllegalArgumentException("alpha must be between 0 and 255.");
    }

    @NonNull
    @RequiresApi(26)
    public static Color compositeColors(@NonNull Color color, @NonNull Color color2) {
        return Api26Impl.compositeColors(color, color2);
    }

    private static int constrain(int i7, int i8, int i9) {
        return i7 < i8 ? i8 : Math.min(i7, i9);
    }
}
