package androidx.core.widget;

import android.content.res.Resources;
import android.os.SystemClock;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.AnimationUtils;
import android.view.animation.Interpolator;
import androidx.annotation.NonNull;
import androidx.core.view.ViewCompat;
import com.google.firebase.iid.z;

public abstract class AutoScrollHelper implements View.OnTouchListener {
    private static final int DEFAULT_ACTIVATION_DELAY = ViewConfiguration.getTapTimeout();
    private static final int DEFAULT_EDGE_TYPE = 1;
    private static final float DEFAULT_MAXIMUM_EDGE = Float.MAX_VALUE;
    private static final int DEFAULT_MAXIMUM_VELOCITY_DIPS = 1575;
    private static final int DEFAULT_MINIMUM_VELOCITY_DIPS = 315;
    private static final int DEFAULT_RAMP_DOWN_DURATION = 500;
    private static final int DEFAULT_RAMP_UP_DURATION = 500;
    private static final float DEFAULT_RELATIVE_EDGE = 0.2f;
    private static final float DEFAULT_RELATIVE_VELOCITY = 1.0f;
    public static final int EDGE_TYPE_INSIDE = 0;
    public static final int EDGE_TYPE_INSIDE_EXTEND = 1;
    public static final int EDGE_TYPE_OUTSIDE = 2;
    private static final int HORIZONTAL = 0;
    public static final float NO_MAX = Float.MAX_VALUE;
    public static final float NO_MIN = 0.0f;
    public static final float RELATIVE_UNSPECIFIED = 0.0f;
    private static final int VERTICAL = 1;
    private int mActivationDelay;
    private boolean mAlreadyDelayed;
    boolean mAnimating;
    private final Interpolator mEdgeInterpolator = new AccelerateInterpolator();
    private int mEdgeType;
    private boolean mEnabled;
    private boolean mExclusive;
    private float[] mMaximumEdges = {Float.MAX_VALUE, Float.MAX_VALUE};
    private float[] mMaximumVelocity = {Float.MAX_VALUE, Float.MAX_VALUE};
    private float[] mMinimumVelocity = {0.0f, 0.0f};
    boolean mNeedsCancel;
    boolean mNeedsReset;
    private float[] mRelativeEdges = {0.0f, 0.0f};
    private float[] mRelativeVelocity = {0.0f, 0.0f};
    private Runnable mRunnable;
    final ClampedScroller mScroller = new ClampedScroller();
    final View mTarget;

    /* access modifiers changed from: private */
    public static class ClampedScroller {
        private long mDeltaTime = 0;
        private int mDeltaX = 0;
        private int mDeltaY = 0;
        private int mEffectiveRampDown;
        private int mRampDownDuration;
        private int mRampUpDuration;
        private long mStartTime = Long.MIN_VALUE;
        private long mStopTime = -1;
        private float mStopValue;
        private float mTargetVelocityX;
        private float mTargetVelocityY;

        ClampedScroller() {
        }

        private float getValueAt(long j7) {
            long j8 = this.mStartTime;
            if (j7 < j8) {
                return 0.0f;
            }
            long j9 = this.mStopTime;
            if (j9 < 0 || j7 < j9) {
                return AutoScrollHelper.constrain(((float) (j7 - j8)) / ((float) this.mRampUpDuration), 0.0f, 1.0f) * 0.5f;
            }
            float f7 = this.mStopValue;
            return (1.0f - f7) + (f7 * AutoScrollHelper.constrain(((float) (j7 - j9)) / ((float) this.mEffectiveRampDown), 0.0f, 1.0f));
        }

        private float interpolateValue(float f7) {
            return (-4.0f * f7 * f7) + (f7 * 4.0f);
        }

        public void computeScrollDelta() {
            if (this.mDeltaTime != 0) {
                long currentAnimationTimeMillis = AnimationUtils.currentAnimationTimeMillis();
                float interpolateValue = interpolateValue(getValueAt(currentAnimationTimeMillis));
                this.mDeltaTime = currentAnimationTimeMillis;
                float f7 = ((float) (currentAnimationTimeMillis - this.mDeltaTime)) * interpolateValue;
                this.mDeltaX = (int) (this.mTargetVelocityX * f7);
                this.mDeltaY = (int) (f7 * this.mTargetVelocityY);
                return;
            }
            throw new RuntimeException("Cannot compute scroll delta before calling start()");
        }

        public int getDeltaX() {
            return this.mDeltaX;
        }

        public int getDeltaY() {
            return this.mDeltaY;
        }

        public int getHorizontalDirection() {
            float f7 = this.mTargetVelocityX;
            return (int) (f7 / Math.abs(f7));
        }

        public int getVerticalDirection() {
            float f7 = this.mTargetVelocityY;
            return (int) (f7 / Math.abs(f7));
        }

        public boolean isFinished() {
            return this.mStopTime > 0 && AnimationUtils.currentAnimationTimeMillis() > this.mStopTime + ((long) this.mEffectiveRampDown);
        }

        public void requestStop() {
            long currentAnimationTimeMillis = AnimationUtils.currentAnimationTimeMillis();
            this.mEffectiveRampDown = AutoScrollHelper.constrain((int) (currentAnimationTimeMillis - this.mStartTime), 0, this.mRampDownDuration);
            this.mStopValue = getValueAt(currentAnimationTimeMillis);
            this.mStopTime = currentAnimationTimeMillis;
        }

        public void setRampDownDuration(int i7) {
            this.mRampDownDuration = i7;
        }

        public void setRampUpDuration(int i7) {
            this.mRampUpDuration = i7;
        }

        public void setTargetVelocity(float f7, float f8) {
            this.mTargetVelocityX = f7;
            this.mTargetVelocityY = f8;
        }

        public void start() {
            long currentAnimationTimeMillis = AnimationUtils.currentAnimationTimeMillis();
            this.mStartTime = currentAnimationTimeMillis;
            this.mStopTime = -1;
            this.mDeltaTime = currentAnimationTimeMillis;
            this.mStopValue = 0.5f;
            this.mDeltaX = 0;
            this.mDeltaY = 0;
        }
    }

    /* access modifiers changed from: private */
    public class ScrollAnimationRunnable implements Runnable {
        ScrollAnimationRunnable() {
        }

        public void run() {
            AutoScrollHelper autoScrollHelper = AutoScrollHelper.this;
            if (autoScrollHelper.mAnimating) {
                if (autoScrollHelper.mNeedsReset) {
                    autoScrollHelper.mNeedsReset = false;
                    autoScrollHelper.mScroller.start();
                }
                ClampedScroller clampedScroller = AutoScrollHelper.this.mScroller;
                if (clampedScroller.isFinished() || !AutoScrollHelper.this.shouldAnimate()) {
                    AutoScrollHelper.this.mAnimating = false;
                    return;
                }
                AutoScrollHelper autoScrollHelper2 = AutoScrollHelper.this;
                if (autoScrollHelper2.mNeedsCancel) {
                    autoScrollHelper2.mNeedsCancel = false;
                    autoScrollHelper2.cancelTargetTouch();
                }
                clampedScroller.computeScrollDelta();
                AutoScrollHelper.this.scrollTargetBy(clampedScroller.getDeltaX(), clampedScroller.getDeltaY());
                ViewCompat.postOnAnimation(AutoScrollHelper.this.mTarget, this);
            }
        }
    }

    public AutoScrollHelper(@NonNull View view) {
        this.mTarget = view;
        float f7 = Resources.getSystem().getDisplayMetrics().density;
        float f8 = (float) ((int) ((1575.0f * f7) + 0.5f));
        setMaximumVelocity(f8, f8);
        float f9 = (float) ((int) ((f7 * 315.0f) + 0.5f));
        setMinimumVelocity(f9, f9);
        setEdgeType(1);
        setMaximumEdges(Float.MAX_VALUE, Float.MAX_VALUE);
        setRelativeEdges(0.2f, 0.2f);
        setRelativeVelocity(1.0f, 1.0f);
        setActivationDelay(DEFAULT_ACTIVATION_DELAY);
        setRampUpDuration(z.f14061f);
        setRampDownDuration(z.f14061f);
    }

    private float computeTargetVelocity(int i7, float f7, float f8, float f9) {
        float edgeValue = getEdgeValue(this.mRelativeEdges[i7], f8, this.mMaximumEdges[i7], f7);
        int i8 = (edgeValue > 0.0f ? 1 : (edgeValue == 0.0f ? 0 : -1));
        if (i8 == 0) {
            return 0.0f;
        }
        float f10 = this.mRelativeVelocity[i7];
        float f11 = this.mMinimumVelocity[i7];
        float f12 = this.mMaximumVelocity[i7];
        float f13 = f10 * f9;
        return i8 > 0 ? constrain(edgeValue * f13, f11, f12) : -constrain((-edgeValue) * f13, f11, f12);
    }

    static float constrain(float f7, float f8, float f9) {
        if (f7 > f9) {
            return f9;
        }
        return f7 < f8 ? f8 : f7;
    }

    private float constrainEdgeValue(float f7, float f8) {
        if (f8 == 0.0f) {
            return 0.0f;
        }
        int i7 = this.mEdgeType;
        if (i7 == 0 || i7 == 1) {
            if (f7 < f8) {
                return f7 >= 0.0f ? 1.0f - (f7 / f8) : (!this.mAnimating || i7 != 1) ? 0.0f : 1.0f;
            }
        } else if (i7 == 2 && f7 < 0.0f) {
            return f7 / (-f8);
        }
    }

    private float getEdgeValue(float f7, float f8, float f9, float f10) {
        float f11;
        float constrain = constrain(f7 * f8, 0.0f, f9);
        float constrainEdgeValue = constrainEdgeValue(f8 - f10, constrain) - constrainEdgeValue(f10, constrain);
        if (constrainEdgeValue < 0.0f) {
            f11 = -this.mEdgeInterpolator.getInterpolation(-constrainEdgeValue);
        } else if (constrainEdgeValue <= 0.0f) {
            return 0.0f;
        } else {
            f11 = this.mEdgeInterpolator.getInterpolation(constrainEdgeValue);
        }
        return constrain(f11, -1.0f, 1.0f);
    }

    private void requestStop() {
        if (this.mNeedsReset) {
            this.mAnimating = false;
        } else {
            this.mScroller.requestStop();
        }
    }

    private void startAnimating() {
        int i7;
        if (this.mRunnable == null) {
            this.mRunnable = new ScrollAnimationRunnable();
        }
        this.mAnimating = true;
        this.mNeedsReset = true;
        if (this.mAlreadyDelayed || (i7 = this.mActivationDelay) <= 0) {
            this.mRunnable.run();
        } else {
            ViewCompat.postOnAnimationDelayed(this.mTarget, this.mRunnable, (long) i7);
        }
        this.mAlreadyDelayed = true;
    }

    public abstract boolean canTargetScrollHorizontally(int i7);

    public abstract boolean canTargetScrollVertically(int i7);

    /* access modifiers changed from: package-private */
    public void cancelTargetTouch() {
        long uptimeMillis = SystemClock.uptimeMillis();
        MotionEvent obtain = MotionEvent.obtain(uptimeMillis, uptimeMillis, 3, 0.0f, 0.0f, 0);
        this.mTarget.onTouchEvent(obtain);
        obtain.recycle();
    }

    public boolean isEnabled() {
        return this.mEnabled;
    }

    public boolean isExclusive() {
        return this.mExclusive;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0013, code lost:
        if (r0 != 3) goto L_0x0058;
     */
    public boolean onTouch(View view, MotionEvent motionEvent) {
        if (!this.mEnabled) {
            return false;
        }
        int actionMasked = motionEvent.getActionMasked();
        if (actionMasked != 0) {
            if (actionMasked != 1) {
                if (actionMasked != 2) {
                }
            }
            requestStop();
            return this.mExclusive && this.mAnimating;
        }
        this.mNeedsCancel = true;
        this.mAlreadyDelayed = false;
        this.mScroller.setTargetVelocity(computeTargetVelocity(0, motionEvent.getX(), (float) view.getWidth(), (float) this.mTarget.getWidth()), computeTargetVelocity(1, motionEvent.getY(), (float) view.getHeight(), (float) this.mTarget.getHeight()));
        if (!this.mAnimating && shouldAnimate()) {
            startAnimating();
        }
        if (this.mExclusive) {
            return false;
        }
    }

    public abstract void scrollTargetBy(int i7, int i8);

    @NonNull
    public AutoScrollHelper setActivationDelay(int i7) {
        this.mActivationDelay = i7;
        return this;
    }

    @NonNull
    public AutoScrollHelper setEdgeType(int i7) {
        this.mEdgeType = i7;
        return this;
    }

    public AutoScrollHelper setEnabled(boolean z7) {
        if (this.mEnabled && !z7) {
            requestStop();
        }
        this.mEnabled = z7;
        return this;
    }

    public AutoScrollHelper setExclusive(boolean z7) {
        this.mExclusive = z7;
        return this;
    }

    @NonNull
    public AutoScrollHelper setMaximumEdges(float f7, float f8) {
        float[] fArr = this.mMaximumEdges;
        fArr[0] = f7;
        fArr[1] = f8;
        return this;
    }

    @NonNull
    public AutoScrollHelper setMaximumVelocity(float f7, float f8) {
        float[] fArr = this.mMaximumVelocity;
        fArr[0] = f7 / 1000.0f;
        fArr[1] = f8 / 1000.0f;
        return this;
    }

    @NonNull
    public AutoScrollHelper setMinimumVelocity(float f7, float f8) {
        float[] fArr = this.mMinimumVelocity;
        fArr[0] = f7 / 1000.0f;
        fArr[1] = f8 / 1000.0f;
        return this;
    }

    @NonNull
    public AutoScrollHelper setRampDownDuration(int i7) {
        this.mScroller.setRampDownDuration(i7);
        return this;
    }

    @NonNull
    public AutoScrollHelper setRampUpDuration(int i7) {
        this.mScroller.setRampUpDuration(i7);
        return this;
    }

    @NonNull
    public AutoScrollHelper setRelativeEdges(float f7, float f8) {
        float[] fArr = this.mRelativeEdges;
        fArr[0] = f7;
        fArr[1] = f8;
        return this;
    }

    @NonNull
    public AutoScrollHelper setRelativeVelocity(float f7, float f8) {
        float[] fArr = this.mRelativeVelocity;
        fArr[0] = f7 / 1000.0f;
        fArr[1] = f8 / 1000.0f;
        return this;
    }

    /* access modifiers changed from: package-private */
    public boolean shouldAnimate() {
        ClampedScroller clampedScroller = this.mScroller;
        int verticalDirection = clampedScroller.getVerticalDirection();
        int horizontalDirection = clampedScroller.getHorizontalDirection();
        return (verticalDirection != 0 && canTargetScrollVertically(verticalDirection)) || (horizontalDirection != 0 && canTargetScrollHorizontally(horizontalDirection));
    }

    static int constrain(int i7, int i8, int i9) {
        if (i7 > i9) {
            return i9;
        }
        return i7 < i8 ? i8 : i7;
    }
}
