package androidx.customview.widget;

import android.content.Context;
import android.util.Log;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.animation.Interpolator;
import android.widget.OverScroller;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.Px;
import androidx.core.view.ViewCompat;
import java.util.Arrays;

public class ViewDragHelper {
    private static final int BASE_SETTLE_DURATION = 256;
    public static final int DIRECTION_ALL = 3;
    public static final int DIRECTION_HORIZONTAL = 1;
    public static final int DIRECTION_VERTICAL = 2;
    public static final int EDGE_ALL = 15;
    public static final int EDGE_BOTTOM = 8;
    public static final int EDGE_LEFT = 1;
    public static final int EDGE_RIGHT = 2;
    private static final int EDGE_SIZE = 20;
    public static final int EDGE_TOP = 4;
    public static final int INVALID_POINTER = -1;
    private static final int MAX_SETTLE_DURATION = 600;
    public static final int STATE_DRAGGING = 1;
    public static final int STATE_IDLE = 0;
    public static final int STATE_SETTLING = 2;
    private static final String TAG = "ViewDragHelper";
    private static final Interpolator sInterpolator = new Interpolator() {
        /* class androidx.customview.widget.ViewDragHelper.AnonymousClass1 */

        public float getInterpolation(float f7) {
            float f8 = f7 - 1.0f;
            return (f8 * f8 * f8 * f8 * f8) + 1.0f;
        }
    };
    private int mActivePointerId = -1;
    private final Callback mCallback;
    private View mCapturedView;
    private final int mDefaultEdgeSize;
    private int mDragState;
    private int[] mEdgeDragsInProgress;
    private int[] mEdgeDragsLocked;
    private int mEdgeSize;
    private int[] mInitialEdgesTouched;
    private float[] mInitialMotionX;
    private float[] mInitialMotionY;
    private float[] mLastMotionX;
    private float[] mLastMotionY;
    private float mMaxVelocity;
    private float mMinVelocity;
    private final ViewGroup mParentView;
    private int mPointersDown;
    private boolean mReleaseInProgress;
    private OverScroller mScroller;
    private final Runnable mSetIdleRunnable = new Runnable() {
        /* class androidx.customview.widget.ViewDragHelper.AnonymousClass2 */

        public void run() {
            ViewDragHelper.this.setDragState(0);
        }
    };
    private int mTouchSlop;
    private int mTrackingEdges;
    private VelocityTracker mVelocityTracker;

    public static abstract class Callback {
        public int clampViewPositionHorizontal(@NonNull View view, int i7, int i8) {
            return 0;
        }

        public int clampViewPositionVertical(@NonNull View view, int i7, int i8) {
            return 0;
        }

        public int getOrderedChildIndex(int i7) {
            return i7;
        }

        public int getViewHorizontalDragRange(@NonNull View view) {
            return 0;
        }

        public int getViewVerticalDragRange(@NonNull View view) {
            return 0;
        }

        public void onEdgeDragStarted(int i7, int i8) {
        }

        public boolean onEdgeLock(int i7) {
            return false;
        }

        public void onEdgeTouched(int i7, int i8) {
        }

        public void onViewCaptured(@NonNull View view, int i7) {
        }

        public void onViewDragStateChanged(int i7) {
        }

        public void onViewPositionChanged(@NonNull View view, int i7, int i8, @Px int i9, @Px int i10) {
        }

        public void onViewReleased(@NonNull View view, float f7, float f8) {
        }

        public abstract boolean tryCaptureView(@NonNull View view, int i7);
    }

    private ViewDragHelper(@NonNull Context context, @NonNull ViewGroup viewGroup, @NonNull Callback callback) {
        if (viewGroup == null) {
            throw new IllegalArgumentException("Parent view may not be null");
        } else if (callback != null) {
            this.mParentView = viewGroup;
            this.mCallback = callback;
            ViewConfiguration viewConfiguration = ViewConfiguration.get(context);
            int i7 = (int) ((context.getResources().getDisplayMetrics().density * 20.0f) + 0.5f);
            this.mDefaultEdgeSize = i7;
            this.mEdgeSize = i7;
            this.mTouchSlop = viewConfiguration.getScaledTouchSlop();
            this.mMaxVelocity = (float) viewConfiguration.getScaledMaximumFlingVelocity();
            this.mMinVelocity = (float) viewConfiguration.getScaledMinimumFlingVelocity();
            this.mScroller = new OverScroller(context, sInterpolator);
        } else {
            throw new IllegalArgumentException("Callback may not be null");
        }
    }

    private boolean checkNewEdgeDrag(float f7, float f8, int i7, int i8) {
        float abs = Math.abs(f7);
        float abs2 = Math.abs(f8);
        if ((this.mInitialEdgesTouched[i7] & i8) != i8 || (this.mTrackingEdges & i8) == 0 || (this.mEdgeDragsLocked[i7] & i8) == i8 || (this.mEdgeDragsInProgress[i7] & i8) == i8) {
            return false;
        }
        int i9 = this.mTouchSlop;
        if (abs <= ((float) i9) && abs2 <= ((float) i9)) {
            return false;
        }
        if (abs >= abs2 * 0.5f || !this.mCallback.onEdgeLock(i8)) {
            return (this.mEdgeDragsInProgress[i7] & i8) == 0 && abs > ((float) this.mTouchSlop);
        }
        int[] iArr = this.mEdgeDragsLocked;
        iArr[i7] = iArr[i7] | i8;
        return false;
    }

    private float clampMag(float f7, float f8, float f9) {
        float abs = Math.abs(f7);
        if (abs < f8) {
            return 0.0f;
        }
        if (abs > f9) {
            return f7 > 0.0f ? f9 : -f9;
        }
        return f7;
    }

    private void clearMotionHistory() {
        float[] fArr = this.mInitialMotionX;
        if (fArr != null) {
            Arrays.fill(fArr, 0.0f);
            Arrays.fill(this.mInitialMotionY, 0.0f);
            Arrays.fill(this.mLastMotionX, 0.0f);
            Arrays.fill(this.mLastMotionY, 0.0f);
            Arrays.fill(this.mInitialEdgesTouched, 0);
            Arrays.fill(this.mEdgeDragsInProgress, 0);
            Arrays.fill(this.mEdgeDragsLocked, 0);
            this.mPointersDown = 0;
        }
    }

    private int computeAxisDuration(int i7, int i8, int i9) {
        if (i7 == 0) {
            return 0;
        }
        int width = this.mParentView.getWidth();
        float f7 = (float) (width / 2);
        float distanceInfluenceForSnapDuration = f7 + (distanceInfluenceForSnapDuration(Math.min(1.0f, ((float) Math.abs(i7)) / ((float) width))) * f7);
        int abs = Math.abs(i8);
        return Math.min(abs > 0 ? Math.round(Math.abs(distanceInfluenceForSnapDuration / ((float) abs)) * 1000.0f) * 4 : (int) (((((float) Math.abs(i7)) / ((float) i9)) + 1.0f) * 256.0f), (int) MAX_SETTLE_DURATION);
    }

    private int computeSettleDuration(View view, int i7, int i8, int i9, int i10) {
        float f7;
        float f8;
        float f9;
        float f10;
        int clampMag = clampMag(i9, (int) this.mMinVelocity, (int) this.mMaxVelocity);
        int clampMag2 = clampMag(i10, (int) this.mMinVelocity, (int) this.mMaxVelocity);
        int abs = Math.abs(i7);
        int abs2 = Math.abs(i8);
        int abs3 = Math.abs(clampMag);
        int abs4 = Math.abs(clampMag2);
        int i11 = abs3 + abs4;
        int i12 = abs + abs2;
        if (clampMag != 0) {
            f8 = (float) abs3;
            f7 = (float) i11;
        } else {
            f8 = (float) abs;
            f7 = (float) i12;
        }
        float f11 = f8 / f7;
        if (clampMag2 != 0) {
            f10 = (float) abs4;
            f9 = (float) i11;
        } else {
            f10 = (float) abs2;
            f9 = (float) i12;
        }
        float f12 = f10 / f9;
        return (int) ((((float) computeAxisDuration(i7, clampMag, this.mCallback.getViewHorizontalDragRange(view))) * f11) + (((float) computeAxisDuration(i8, clampMag2, this.mCallback.getViewVerticalDragRange(view))) * f12));
    }

    public static ViewDragHelper create(@NonNull ViewGroup viewGroup, float f7, @NonNull Callback callback) {
        ViewDragHelper create = create(viewGroup, callback);
        create.mTouchSlop = (int) (((float) create.mTouchSlop) * (1.0f / f7));
        return create;
    }

    private void dispatchViewReleased(float f7, float f8) {
        this.mReleaseInProgress = true;
        this.mCallback.onViewReleased(this.mCapturedView, f7, f8);
        this.mReleaseInProgress = false;
        if (this.mDragState == 1) {
            setDragState(0);
        }
    }

    private float distanceInfluenceForSnapDuration(float f7) {
        return (float) Math.sin((double) ((f7 - 0.5f) * 0.47123894f));
    }

    private void dragTo(int i7, int i8, int i9, int i10) {
        int left = this.mCapturedView.getLeft();
        int top = this.mCapturedView.getTop();
        if (i9 != 0) {
            i7 = this.mCallback.clampViewPositionHorizontal(this.mCapturedView, i7, i9);
            ViewCompat.offsetLeftAndRight(this.mCapturedView, i7 - left);
        }
        if (i10 != 0) {
            i8 = this.mCallback.clampViewPositionVertical(this.mCapturedView, i8, i10);
            ViewCompat.offsetTopAndBottom(this.mCapturedView, i8 - top);
        }
        if (i9 != 0 || i10 != 0) {
            this.mCallback.onViewPositionChanged(this.mCapturedView, i7, i8, i7 - left, i8 - top);
        }
    }

    private void ensureMotionHistorySizeForId(int i7) {
        float[] fArr = this.mInitialMotionX;
        if (fArr == null || fArr.length <= i7) {
            int i8 = i7 + 1;
            float[] fArr2 = new float[i8];
            float[] fArr3 = new float[i8];
            float[] fArr4 = new float[i8];
            float[] fArr5 = new float[i8];
            int[] iArr = new int[i8];
            int[] iArr2 = new int[i8];
            int[] iArr3 = new int[i8];
            if (fArr != null) {
                System.arraycopy(fArr, 0, fArr2, 0, fArr.length);
                float[] fArr6 = this.mInitialMotionY;
                System.arraycopy(fArr6, 0, fArr3, 0, fArr6.length);
                float[] fArr7 = this.mLastMotionX;
                System.arraycopy(fArr7, 0, fArr4, 0, fArr7.length);
                float[] fArr8 = this.mLastMotionY;
                System.arraycopy(fArr8, 0, fArr5, 0, fArr8.length);
                int[] iArr4 = this.mInitialEdgesTouched;
                System.arraycopy(iArr4, 0, iArr, 0, iArr4.length);
                int[] iArr5 = this.mEdgeDragsInProgress;
                System.arraycopy(iArr5, 0, iArr2, 0, iArr5.length);
                int[] iArr6 = this.mEdgeDragsLocked;
                System.arraycopy(iArr6, 0, iArr3, 0, iArr6.length);
            }
            this.mInitialMotionX = fArr2;
            this.mInitialMotionY = fArr3;
            this.mLastMotionX = fArr4;
            this.mLastMotionY = fArr5;
            this.mInitialEdgesTouched = iArr;
            this.mEdgeDragsInProgress = iArr2;
            this.mEdgeDragsLocked = iArr3;
        }
    }

    private boolean forceSettleCapturedViewAt(int i7, int i8, int i9, int i10) {
        int left = this.mCapturedView.getLeft();
        int top = this.mCapturedView.getTop();
        int i11 = i7 - left;
        int i12 = i8 - top;
        if (i11 == 0 && i12 == 0) {
            this.mScroller.abortAnimation();
            setDragState(0);
            return false;
        }
        this.mScroller.startScroll(left, top, i11, i12, computeSettleDuration(this.mCapturedView, i11, i12, i9, i10));
        setDragState(2);
        return true;
    }

    private int getEdgesTouched(int i7, int i8) {
        int i9 = i7 < this.mParentView.getLeft() + this.mEdgeSize ? 1 : 0;
        if (i8 < this.mParentView.getTop() + this.mEdgeSize) {
            i9 |= 4;
        }
        if (i7 > this.mParentView.getRight() - this.mEdgeSize) {
            i9 |= 2;
        }
        return i8 > this.mParentView.getBottom() - this.mEdgeSize ? i9 | 8 : i9;
    }

    private boolean isValidPointerForActionMove(int i7) {
        if (isPointerDown(i7)) {
            return true;
        }
        Log.e(TAG, "Ignoring pointerId=" + i7 + " because ACTION_DOWN was not received for this pointer before ACTION_MOVE. It likely happened because  ViewDragHelper did not receive all the events in the event stream.");
        return false;
    }

    private void releaseViewForPointerUp() {
        this.mVelocityTracker.computeCurrentVelocity(1000, this.mMaxVelocity);
        dispatchViewReleased(clampMag(this.mVelocityTracker.getXVelocity(this.mActivePointerId), this.mMinVelocity, this.mMaxVelocity), clampMag(this.mVelocityTracker.getYVelocity(this.mActivePointerId), this.mMinVelocity, this.mMaxVelocity));
    }

    private void reportNewEdgeDrags(float f7, float f8, int i7) {
        boolean checkNewEdgeDrag = checkNewEdgeDrag(f7, f8, i7, 1);
        if (checkNewEdgeDrag(f8, f7, i7, 4)) {
            checkNewEdgeDrag |= true;
        }
        if (checkNewEdgeDrag(f7, f8, i7, 2)) {
            boolean z7 = checkNewEdgeDrag ? 1 : 0;
            char c7 = checkNewEdgeDrag ? 1 : 0;
            checkNewEdgeDrag = z7 | true;
        }
        if (checkNewEdgeDrag(f8, f7, i7, 8)) {
            boolean z8 = checkNewEdgeDrag ? 1 : 0;
            char c8 = checkNewEdgeDrag ? 1 : 0;
            checkNewEdgeDrag = z8 | true;
        }
        if (checkNewEdgeDrag) {
            int[] iArr = this.mEdgeDragsInProgress;
            int i8 = iArr[i7];
            int i9 = checkNewEdgeDrag ? 1 : 0;
            char c9 = checkNewEdgeDrag ? 1 : 0;
            iArr[i7] = i8 | i9;
            Callback callback = this.mCallback;
            int i10 = checkNewEdgeDrag ? 1 : 0;
            int i11 = checkNewEdgeDrag ? 1 : 0;
            int i12 = checkNewEdgeDrag ? 1 : 0;
            int i13 = checkNewEdgeDrag ? 1 : 0;
            callback.onEdgeDragStarted(i10, i7);
        }
    }

    private void saveInitialMotion(float f7, float f8, int i7) {
        ensureMotionHistorySizeForId(i7);
        float[] fArr = this.mInitialMotionX;
        this.mLastMotionX[i7] = f7;
        fArr[i7] = f7;
        float[] fArr2 = this.mInitialMotionY;
        this.mLastMotionY[i7] = f8;
        fArr2[i7] = f8;
        this.mInitialEdgesTouched[i7] = getEdgesTouched((int) f7, (int) f8);
        this.mPointersDown |= 1 << i7;
    }

    private void saveLastMotion(MotionEvent motionEvent) {
        int pointerCount = motionEvent.getPointerCount();
        for (int i7 = 0; i7 < pointerCount; i7++) {
            int pointerId = motionEvent.getPointerId(i7);
            if (isValidPointerForActionMove(pointerId)) {
                float x7 = motionEvent.getX(i7);
                float y7 = motionEvent.getY(i7);
                this.mLastMotionX[pointerId] = x7;
                this.mLastMotionY[pointerId] = y7;
            }
        }
    }

    public void abort() {
        cancel();
        if (this.mDragState == 2) {
            int currX = this.mScroller.getCurrX();
            int currY = this.mScroller.getCurrY();
            this.mScroller.abortAnimation();
            int currX2 = this.mScroller.getCurrX();
            int currY2 = this.mScroller.getCurrY();
            this.mCallback.onViewPositionChanged(this.mCapturedView, currX2, currY2, currX2 - currX, currY2 - currY);
        }
        setDragState(0);
    }

    /* access modifiers changed from: protected */
    public boolean canScroll(@NonNull View view, boolean z7, int i7, int i8, int i9, int i10) {
        int i11;
        if (view instanceof ViewGroup) {
            ViewGroup viewGroup = (ViewGroup) view;
            int scrollX = view.getScrollX();
            int scrollY = view.getScrollY();
            for (int childCount = viewGroup.getChildCount() - 1; childCount >= 0; childCount--) {
                View childAt = viewGroup.getChildAt(childCount);
                int i12 = i9 + scrollX;
                if (i12 >= childAt.getLeft() && i12 < childAt.getRight() && (i11 = i10 + scrollY) >= childAt.getTop() && i11 < childAt.getBottom() && canScroll(childAt, true, i7, i8, i12 - childAt.getLeft(), i11 - childAt.getTop())) {
                    return true;
                }
            }
        }
        return z7 && (view.canScrollHorizontally(-i7) || view.canScrollVertically(-i8));
    }

    public void cancel() {
        this.mActivePointerId = -1;
        clearMotionHistory();
        VelocityTracker velocityTracker = this.mVelocityTracker;
        if (velocityTracker != null) {
            velocityTracker.recycle();
            this.mVelocityTracker = null;
        }
    }

    public void captureChildView(@NonNull View view, int i7) {
        if (view.getParent() == this.mParentView) {
            this.mCapturedView = view;
            this.mActivePointerId = i7;
            this.mCallback.onViewCaptured(view, i7);
            setDragState(1);
            return;
        }
        throw new IllegalArgumentException("captureChildView: parameter must be a descendant of the ViewDragHelper's tracked parent view (" + this.mParentView + ")");
    }

    public boolean checkTouchSlop(int i7) {
        int length = this.mInitialMotionX.length;
        for (int i8 = 0; i8 < length; i8++) {
            if (checkTouchSlop(i7, i8)) {
                return true;
            }
        }
        return false;
    }

    public boolean continueSettling(boolean z7) {
        if (this.mDragState == 2) {
            boolean computeScrollOffset = this.mScroller.computeScrollOffset();
            int currX = this.mScroller.getCurrX();
            int currY = this.mScroller.getCurrY();
            int left = currX - this.mCapturedView.getLeft();
            int top = currY - this.mCapturedView.getTop();
            if (left != 0) {
                ViewCompat.offsetLeftAndRight(this.mCapturedView, left);
            }
            if (top != 0) {
                ViewCompat.offsetTopAndBottom(this.mCapturedView, top);
            }
            if (!(left == 0 && top == 0)) {
                this.mCallback.onViewPositionChanged(this.mCapturedView, currX, currY, left, top);
            }
            if (computeScrollOffset && currX == this.mScroller.getFinalX() && currY == this.mScroller.getFinalY()) {
                this.mScroller.abortAnimation();
                computeScrollOffset = false;
            }
            if (!computeScrollOffset) {
                if (z7) {
                    this.mParentView.post(this.mSetIdleRunnable);
                } else {
                    setDragState(0);
                }
            }
        }
        return this.mDragState == 2;
    }

    @Nullable
    public View findTopChildUnder(int i7, int i8) {
        for (int childCount = this.mParentView.getChildCount() - 1; childCount >= 0; childCount--) {
            View childAt = this.mParentView.getChildAt(this.mCallback.getOrderedChildIndex(childCount));
            if (i7 >= childAt.getLeft() && i7 < childAt.getRight() && i8 >= childAt.getTop() && i8 < childAt.getBottom()) {
                return childAt;
            }
        }
        return null;
    }

    public void flingCapturedView(int i7, int i8, int i9, int i10) {
        if (this.mReleaseInProgress) {
            this.mScroller.fling(this.mCapturedView.getLeft(), this.mCapturedView.getTop(), (int) this.mVelocityTracker.getXVelocity(this.mActivePointerId), (int) this.mVelocityTracker.getYVelocity(this.mActivePointerId), i7, i9, i8, i10);
            setDragState(2);
            return;
        }
        throw new IllegalStateException("Cannot flingCapturedView outside of a call to Callback#onViewReleased");
    }

    public int getActivePointerId() {
        return this.mActivePointerId;
    }

    @Nullable
    public View getCapturedView() {
        return this.mCapturedView;
    }

    @Px
    public int getDefaultEdgeSize() {
        return this.mDefaultEdgeSize;
    }

    @Px
    public int getEdgeSize() {
        return this.mEdgeSize;
    }

    public float getMinVelocity() {
        return this.mMinVelocity;
    }

    @Px
    public int getTouchSlop() {
        return this.mTouchSlop;
    }

    public int getViewDragState() {
        return this.mDragState;
    }

    public boolean isCapturedViewUnder(int i7, int i8) {
        return isViewUnder(this.mCapturedView, i7, i8);
    }

    public boolean isEdgeTouched(int i7) {
        int length = this.mInitialEdgesTouched.length;
        for (int i8 = 0; i8 < length; i8++) {
            if (isEdgeTouched(i7, i8)) {
                return true;
            }
        }
        return false;
    }

    public boolean isPointerDown(int i7) {
        return (this.mPointersDown & (1 << i7)) != 0;
    }

    public boolean isViewUnder(@Nullable View view, int i7, int i8) {
        return view != null && i7 >= view.getLeft() && i7 < view.getRight() && i8 >= view.getTop() && i8 < view.getBottom();
    }

    public void processTouchEvent(@NonNull MotionEvent motionEvent) {
        int i7;
        int actionMasked = motionEvent.getActionMasked();
        int actionIndex = motionEvent.getActionIndex();
        if (actionMasked == 0) {
            cancel();
        }
        if (this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        }
        this.mVelocityTracker.addMovement(motionEvent);
        int i8 = 0;
        if (actionMasked != 0) {
            if (actionMasked != 1) {
                if (actionMasked == 2) {
                    if (this.mDragState != 1) {
                        int pointerCount = motionEvent.getPointerCount();
                        while (i8 < pointerCount) {
                            int pointerId = motionEvent.getPointerId(i8);
                            if (isValidPointerForActionMove(pointerId)) {
                                float x7 = motionEvent.getX(i8);
                                float y7 = motionEvent.getY(i8);
                                float f7 = x7 - this.mInitialMotionX[pointerId];
                                float f8 = y7 - this.mInitialMotionY[pointerId];
                                reportNewEdgeDrags(f7, f8, pointerId);
                                if (this.mDragState != 1) {
                                    View findTopChildUnder = findTopChildUnder((int) x7, (int) y7);
                                    if (checkTouchSlop(findTopChildUnder, f7, f8) && tryCaptureViewForDrag(findTopChildUnder, pointerId)) {
                                        break;
                                    }
                                } else {
                                    break;
                                }
                            }
                            i8++;
                        }
                    } else if (isValidPointerForActionMove(this.mActivePointerId)) {
                        int findPointerIndex = motionEvent.findPointerIndex(this.mActivePointerId);
                        float x8 = motionEvent.getX(findPointerIndex);
                        float y8 = motionEvent.getY(findPointerIndex);
                        float[] fArr = this.mLastMotionX;
                        int i9 = this.mActivePointerId;
                        int i10 = (int) (x8 - fArr[i9]);
                        int i11 = (int) (y8 - this.mLastMotionY[i9]);
                        dragTo(this.mCapturedView.getLeft() + i10, this.mCapturedView.getTop() + i11, i10, i11);
                    } else {
                        return;
                    }
                    saveLastMotion(motionEvent);
                    return;
                } else if (actionMasked != 3) {
                    if (actionMasked == 5) {
                        int pointerId2 = motionEvent.getPointerId(actionIndex);
                        float x9 = motionEvent.getX(actionIndex);
                        float y9 = motionEvent.getY(actionIndex);
                        saveInitialMotion(x9, y9, pointerId2);
                        if (this.mDragState == 0) {
                            tryCaptureViewForDrag(findTopChildUnder((int) x9, (int) y9), pointerId2);
                            int i12 = this.mInitialEdgesTouched[pointerId2];
                            int i13 = this.mTrackingEdges;
                            if ((i12 & i13) != 0) {
                                this.mCallback.onEdgeTouched(i12 & i13, pointerId2);
                                return;
                            }
                            return;
                        } else if (isCapturedViewUnder((int) x9, (int) y9)) {
                            tryCaptureViewForDrag(this.mCapturedView, pointerId2);
                            return;
                        } else {
                            return;
                        }
                    } else if (actionMasked == 6) {
                        int pointerId3 = motionEvent.getPointerId(actionIndex);
                        if (this.mDragState == 1 && pointerId3 == this.mActivePointerId) {
                            int pointerCount2 = motionEvent.getPointerCount();
                            while (true) {
                                if (i8 >= pointerCount2) {
                                    i7 = -1;
                                    break;
                                }
                                int pointerId4 = motionEvent.getPointerId(i8);
                                if (pointerId4 != this.mActivePointerId) {
                                    View findTopChildUnder2 = findTopChildUnder((int) motionEvent.getX(i8), (int) motionEvent.getY(i8));
                                    View view = this.mCapturedView;
                                    if (findTopChildUnder2 == view && tryCaptureViewForDrag(view, pointerId4)) {
                                        i7 = this.mActivePointerId;
                                        break;
                                    }
                                }
                                i8++;
                            }
                            if (i7 == -1) {
                                releaseViewForPointerUp();
                            }
                        }
                        clearMotionHistory(pointerId3);
                        return;
                    } else {
                        return;
                    }
                } else if (this.mDragState == 1) {
                    dispatchViewReleased(0.0f, 0.0f);
                }
            } else if (this.mDragState == 1) {
                releaseViewForPointerUp();
            }
            cancel();
            return;
        }
        float x10 = motionEvent.getX();
        float y10 = motionEvent.getY();
        int pointerId5 = motionEvent.getPointerId(0);
        View findTopChildUnder3 = findTopChildUnder((int) x10, (int) y10);
        saveInitialMotion(x10, y10, pointerId5);
        tryCaptureViewForDrag(findTopChildUnder3, pointerId5);
        int i14 = this.mInitialEdgesTouched[pointerId5];
        int i15 = this.mTrackingEdges;
        if ((i14 & i15) != 0) {
            this.mCallback.onEdgeTouched(i14 & i15, pointerId5);
        }
    }

    /* access modifiers changed from: package-private */
    public void setDragState(int i7) {
        this.mParentView.removeCallbacks(this.mSetIdleRunnable);
        if (this.mDragState != i7) {
            this.mDragState = i7;
            this.mCallback.onViewDragStateChanged(i7);
            if (this.mDragState == 0) {
                this.mCapturedView = null;
            }
        }
    }

    public void setEdgeSize(@IntRange(from = 0) @Px int i7) {
        this.mEdgeSize = i7;
    }

    public void setEdgeTrackingEnabled(int i7) {
        this.mTrackingEdges = i7;
    }

    public void setMinVelocity(float f7) {
        this.mMinVelocity = f7;
    }

    public boolean settleCapturedViewAt(int i7, int i8) {
        if (this.mReleaseInProgress) {
            return forceSettleCapturedViewAt(i7, i8, (int) this.mVelocityTracker.getXVelocity(this.mActivePointerId), (int) this.mVelocityTracker.getYVelocity(this.mActivePointerId));
        }
        throw new IllegalStateException("Cannot settleCapturedViewAt outside of a call to Callback#onViewReleased");
    }

    /* JADX WARNING: Code restructure failed: missing block: B:45:0x00dd, code lost:
        if (r12 != r11) goto L_0x00e6;
     */
    public boolean shouldInterceptTouchEvent(@NonNull MotionEvent motionEvent) {
        boolean z7;
        View findTopChildUnder;
        int actionMasked = motionEvent.getActionMasked();
        int actionIndex = motionEvent.getActionIndex();
        if (actionMasked == 0) {
            cancel();
        }
        if (this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        }
        this.mVelocityTracker.addMovement(motionEvent);
        if (actionMasked != 0) {
            if (actionMasked != 1) {
                if (actionMasked != 2) {
                    if (actionMasked != 3) {
                        if (actionMasked == 5) {
                            int pointerId = motionEvent.getPointerId(actionIndex);
                            float x7 = motionEvent.getX(actionIndex);
                            float y7 = motionEvent.getY(actionIndex);
                            saveInitialMotion(x7, y7, pointerId);
                            int i7 = this.mDragState;
                            if (i7 == 0) {
                                int i8 = this.mInitialEdgesTouched[pointerId];
                                int i9 = this.mTrackingEdges;
                                if ((i8 & i9) != 0) {
                                    this.mCallback.onEdgeTouched(i8 & i9, pointerId);
                                }
                            } else if (i7 == 2 && (findTopChildUnder = findTopChildUnder((int) x7, (int) y7)) == this.mCapturedView) {
                                tryCaptureViewForDrag(findTopChildUnder, pointerId);
                            }
                        } else if (actionMasked == 6) {
                            clearMotionHistory(motionEvent.getPointerId(actionIndex));
                        }
                    }
                } else if (!(this.mInitialMotionX == null || this.mInitialMotionY == null)) {
                    int pointerCount = motionEvent.getPointerCount();
                    for (int i10 = 0; i10 < pointerCount; i10++) {
                        int pointerId2 = motionEvent.getPointerId(i10);
                        if (isValidPointerForActionMove(pointerId2)) {
                            float x8 = motionEvent.getX(i10);
                            float y8 = motionEvent.getY(i10);
                            float f7 = x8 - this.mInitialMotionX[pointerId2];
                            float f8 = y8 - this.mInitialMotionY[pointerId2];
                            View findTopChildUnder2 = findTopChildUnder((int) x8, (int) y8);
                            boolean z8 = findTopChildUnder2 != null && checkTouchSlop(findTopChildUnder2, f7, f8);
                            if (z8) {
                                int left = findTopChildUnder2.getLeft();
                                int i11 = (int) f7;
                                int clampViewPositionHorizontal = this.mCallback.clampViewPositionHorizontal(findTopChildUnder2, left + i11, i11);
                                int top = findTopChildUnder2.getTop();
                                int i12 = (int) f8;
                                int clampViewPositionVertical = this.mCallback.clampViewPositionVertical(findTopChildUnder2, top + i12, i12);
                                int viewHorizontalDragRange = this.mCallback.getViewHorizontalDragRange(findTopChildUnder2);
                                int viewVerticalDragRange = this.mCallback.getViewVerticalDragRange(findTopChildUnder2);
                                if (viewHorizontalDragRange != 0) {
                                    if (viewHorizontalDragRange > 0) {
                                    }
                                }
                                if (viewVerticalDragRange != 0) {
                                    if (viewVerticalDragRange > 0 && clampViewPositionVertical == top) {
                                        break;
                                    }
                                } else {
                                    break;
                                }
                            }
                            reportNewEdgeDrags(f7, f8, pointerId2);
                            if (this.mDragState != 1) {
                                if (z8 && tryCaptureViewForDrag(findTopChildUnder2, pointerId2)) {
                                    break;
                                }
                            } else {
                                break;
                            }
                        }
                    }
                    saveLastMotion(motionEvent);
                }
                z7 = false;
            }
            cancel();
            z7 = false;
        } else {
            float x9 = motionEvent.getX();
            float y9 = motionEvent.getY();
            z7 = false;
            int pointerId3 = motionEvent.getPointerId(0);
            saveInitialMotion(x9, y9, pointerId3);
            View findTopChildUnder3 = findTopChildUnder((int) x9, (int) y9);
            if (findTopChildUnder3 == this.mCapturedView && this.mDragState == 2) {
                tryCaptureViewForDrag(findTopChildUnder3, pointerId3);
            }
            int i13 = this.mInitialEdgesTouched[pointerId3];
            int i14 = this.mTrackingEdges;
            if ((i13 & i14) != 0) {
                this.mCallback.onEdgeTouched(i13 & i14, pointerId3);
            }
        }
        if (this.mDragState == 1) {
            return true;
        }
        return z7;
    }

    public boolean smoothSlideViewTo(@NonNull View view, int i7, int i8) {
        this.mCapturedView = view;
        this.mActivePointerId = -1;
        boolean forceSettleCapturedViewAt = forceSettleCapturedViewAt(i7, i8, 0, 0);
        if (!forceSettleCapturedViewAt && this.mDragState == 0 && this.mCapturedView != null) {
            this.mCapturedView = null;
        }
        return forceSettleCapturedViewAt;
    }

    /* access modifiers changed from: package-private */
    public boolean tryCaptureViewForDrag(View view, int i7) {
        if (view == this.mCapturedView && this.mActivePointerId == i7) {
            return true;
        }
        if (view == null || !this.mCallback.tryCaptureView(view, i7)) {
            return false;
        }
        this.mActivePointerId = i7;
        captureChildView(view, i7);
        return true;
    }

    private int clampMag(int i7, int i8, int i9) {
        int abs = Math.abs(i7);
        if (abs < i8) {
            return 0;
        }
        if (abs > i9) {
            return i7 > 0 ? i9 : -i9;
        }
        return i7;
    }

    private void clearMotionHistory(int i7) {
        if (this.mInitialMotionX != null && isPointerDown(i7)) {
            this.mInitialMotionX[i7] = 0.0f;
            this.mInitialMotionY[i7] = 0.0f;
            this.mLastMotionX[i7] = 0.0f;
            this.mLastMotionY[i7] = 0.0f;
            this.mInitialEdgesTouched[i7] = 0;
            this.mEdgeDragsInProgress[i7] = 0;
            this.mEdgeDragsLocked[i7] = 0;
            this.mPointersDown = (~(1 << i7)) & this.mPointersDown;
        }
    }

    public static ViewDragHelper create(@NonNull ViewGroup viewGroup, @NonNull Callback callback) {
        return new ViewDragHelper(viewGroup.getContext(), viewGroup, callback);
    }

    public boolean checkTouchSlop(int i7, int i8) {
        if (!isPointerDown(i8)) {
            return false;
        }
        boolean z7 = (i7 & 1) == 1;
        boolean z8 = (i7 & 2) == 2;
        float f7 = this.mLastMotionX[i8] - this.mInitialMotionX[i8];
        float f8 = this.mLastMotionY[i8] - this.mInitialMotionY[i8];
        if (!z7 || !z8) {
            return z7 ? Math.abs(f7) > ((float) this.mTouchSlop) : z8 && Math.abs(f8) > ((float) this.mTouchSlop);
        }
        int i9 = this.mTouchSlop;
        return (f7 * f7) + (f8 * f8) > ((float) (i9 * i9));
    }

    public boolean isEdgeTouched(int i7, int i8) {
        return isPointerDown(i8) && (this.mInitialEdgesTouched[i8] & i7) != 0;
    }

    private boolean checkTouchSlop(View view, float f7, float f8) {
        if (view == null) {
            return false;
        }
        boolean z7 = this.mCallback.getViewHorizontalDragRange(view) > 0;
        boolean z8 = this.mCallback.getViewVerticalDragRange(view) > 0;
        if (!z7 || !z8) {
            return z7 ? Math.abs(f7) > ((float) this.mTouchSlop) : z8 && Math.abs(f8) > ((float) this.mTouchSlop);
        }
        int i7 = this.mTouchSlop;
        return (f7 * f7) + (f8 * f8) > ((float) (i7 * i7));
    }
}
