package androidx.dynamicanimation.animation;

import androidx.annotation.FloatRange;
import androidx.annotation.RestrictTo;
import androidx.dynamicanimation.animation.DynamicAnimation;

public final class SpringForce implements Force {
    public static final float DAMPING_RATIO_HIGH_BOUNCY = 0.2f;
    public static final float DAMPING_RATIO_LOW_BOUNCY = 0.75f;
    public static final float DAMPING_RATIO_MEDIUM_BOUNCY = 0.5f;
    public static final float DAMPING_RATIO_NO_BOUNCY = 1.0f;
    public static final float STIFFNESS_HIGH = 10000.0f;
    public static final float STIFFNESS_LOW = 200.0f;
    public static final float STIFFNESS_MEDIUM = 1500.0f;
    public static final float STIFFNESS_VERY_LOW = 50.0f;
    private static final double UNSET = Double.MAX_VALUE;
    private static final double VELOCITY_THRESHOLD_MULTIPLIER = 62.5d;
    private double mDampedFreq;
    double mDampingRatio = 0.5d;
    private double mFinalPosition = Double.MAX_VALUE;
    private double mGammaMinus;
    private double mGammaPlus;
    private boolean mInitialized = false;
    private final DynamicAnimation.MassState mMassState = new DynamicAnimation.MassState();
    double mNaturalFreq = Math.sqrt(1500.0d);
    private double mValueThreshold;
    private double mVelocityThreshold;

    public SpringForce() {
    }

    private void init() {
        if (!this.mInitialized) {
            if (this.mFinalPosition != Double.MAX_VALUE) {
                double d7 = this.mDampingRatio;
                if (d7 > 1.0d) {
                    double d8 = this.mNaturalFreq;
                    this.mGammaPlus = ((-d7) * d8) + (d8 * Math.sqrt((d7 * d7) - 1.0d));
                    double d9 = this.mDampingRatio;
                    double d10 = this.mNaturalFreq;
                    this.mGammaMinus = ((-d9) * d10) - (d10 * Math.sqrt((d9 * d9) - 1.0d));
                } else if (d7 >= 0.0d && d7 < 1.0d) {
                    this.mDampedFreq = this.mNaturalFreq * Math.sqrt(1.0d - (d7 * d7));
                }
                this.mInitialized = true;
                return;
            }
            throw new IllegalStateException("Error: Final position of the spring must be set before the animation starts");
        }
    }

    @Override // androidx.dynamicanimation.animation.Force
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public float getAcceleration(float f7, float f8) {
        float finalPosition = f7 - getFinalPosition();
        double d7 = this.mNaturalFreq;
        return (float) (((-(d7 * d7)) * ((double) finalPosition)) - (((d7 * 2.0d) * this.mDampingRatio) * ((double) f8)));
    }

    public float getDampingRatio() {
        return (float) this.mDampingRatio;
    }

    public float getFinalPosition() {
        return (float) this.mFinalPosition;
    }

    public float getStiffness() {
        double d7 = this.mNaturalFreq;
        return (float) (d7 * d7);
    }

    @Override // androidx.dynamicanimation.animation.Force
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public boolean isAtEquilibrium(float f7, float f8) {
        return ((double) Math.abs(f8)) < this.mVelocityThreshold && ((double) Math.abs(f7 - getFinalPosition())) < this.mValueThreshold;
    }

    public SpringForce setDampingRatio(@FloatRange(from = 0.0d) float f7) {
        if (f7 >= 0.0f) {
            this.mDampingRatio = (double) f7;
            this.mInitialized = false;
            return this;
        }
        throw new IllegalArgumentException("Damping ratio must be non-negative");
    }

    public SpringForce setFinalPosition(float f7) {
        this.mFinalPosition = (double) f7;
        return this;
    }

    public SpringForce setStiffness(@FloatRange(from = 0.0d, fromInclusive = false) float f7) {
        if (f7 > 0.0f) {
            this.mNaturalFreq = Math.sqrt((double) f7);
            this.mInitialized = false;
            return this;
        }
        throw new IllegalArgumentException("Spring stiffness constant must be positive.");
    }

    /* access modifiers changed from: package-private */
    public void setValueThreshold(double d7) {
        double abs = Math.abs(d7);
        this.mValueThreshold = abs;
        this.mVelocityThreshold = abs * VELOCITY_THRESHOLD_MULTIPLIER;
    }

    /* access modifiers changed from: package-private */
    public DynamicAnimation.MassState updateValues(double d7, double d8, long j7) {
        double d9;
        double d10;
        init();
        double d11 = ((double) j7) / 1000.0d;
        double d12 = d7 - this.mFinalPosition;
        double d13 = this.mDampingRatio;
        if (d13 > 1.0d) {
            double d14 = this.mGammaMinus;
            double d15 = this.mGammaPlus;
            double d16 = d12 - (((d14 * d12) - d8) / (d14 - d15));
            double d17 = ((d12 * d14) - d8) / (d14 - d15);
            d10 = (Math.pow(2.718281828459045d, d14 * d11) * d16) + (Math.pow(2.718281828459045d, this.mGammaPlus * d11) * d17);
            double d18 = this.mGammaMinus;
            double pow = d16 * d18 * Math.pow(2.718281828459045d, d18 * d11);
            double d19 = this.mGammaPlus;
            d9 = pow + (d17 * d19 * Math.pow(2.718281828459045d, d19 * d11));
        } else if (d13 == 1.0d) {
            double d20 = this.mNaturalFreq;
            double d21 = d8 + (d20 * d12);
            double d22 = d12 + (d21 * d11);
            d10 = Math.pow(2.718281828459045d, (-d20) * d11) * d22;
            double pow2 = d22 * Math.pow(2.718281828459045d, (-this.mNaturalFreq) * d11);
            double d23 = this.mNaturalFreq;
            d9 = (d21 * Math.pow(2.718281828459045d, (-d23) * d11)) + (pow2 * (-d23));
        } else {
            double d24 = 1.0d / this.mDampedFreq;
            double d25 = this.mNaturalFreq;
            double d26 = d24 * ((d13 * d25 * d12) + d8);
            double pow3 = Math.pow(2.718281828459045d, (-d13) * d25 * d11) * ((Math.cos(this.mDampedFreq * d11) * d12) + (Math.sin(this.mDampedFreq * d11) * d26));
            double d27 = this.mNaturalFreq;
            double d28 = this.mDampingRatio;
            double pow4 = Math.pow(2.718281828459045d, (-d28) * d27 * d11);
            double d29 = this.mDampedFreq;
            double sin = (-d29) * d12 * Math.sin(d29 * d11);
            double d30 = this.mDampedFreq;
            d9 = ((-d27) * pow3 * d28) + (pow4 * (sin + (d26 * d30 * Math.cos(d30 * d11))));
            d10 = pow3;
        }
        DynamicAnimation.MassState massState = this.mMassState;
        massState.mValue = (float) (d10 + this.mFinalPosition);
        massState.mVelocity = (float) d9;
        return massState;
    }

    public SpringForce(float f7) {
        this.mFinalPosition = (double) f7;
    }
}
