package androidx.emoji2.text;

import android.text.Editable;
import android.text.Selection;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.Spanned;
import android.text.TextPaint;
import android.text.method.MetaKeyKeyListener;
import android.view.KeyEvent;
import android.view.inputmethod.InputConnection;
import androidx.annotation.AnyThread;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.core.graphics.PaintCompat;
import androidx.emoji2.text.EmojiCompat;
import androidx.emoji2.text.MetadataRepo;
import java.util.Arrays;

/* access modifiers changed from: package-private */
@AnyThread
@RequiresApi(19)
@RestrictTo({RestrictTo.Scope.LIBRARY})
public final class EmojiProcessor {
    private static final int ACTION_ADVANCE_BOTH = 1;
    private static final int ACTION_ADVANCE_END = 2;
    private static final int ACTION_FLUSH = 3;
    @Nullable
    private final int[] mEmojiAsDefaultStyleExceptions;
    @NonNull
    private EmojiCompat.GlyphChecker mGlyphChecker;
    @NonNull
    private final MetadataRepo mMetadataRepo;
    @NonNull
    private final EmojiCompat.SpanFactory mSpanFactory;
    private final boolean mUseEmojiAsDefaultStyle;

    /* access modifiers changed from: private */
    @RequiresApi(19)
    public static final class CodepointIndexFinder {
        private static final int INVALID_INDEX = -1;

        private CodepointIndexFinder() {
        }

        static int findIndexBackward(CharSequence charSequence, int i7, int i8) {
            int length = charSequence.length();
            if (i7 < 0 || length < i7 || i8 < 0) {
                return -1;
            }
            while (true) {
                boolean z7 = false;
                while (i8 != 0) {
                    i7--;
                    if (i7 < 0) {
                        return z7 ? -1 : 0;
                    }
                    char charAt = charSequence.charAt(i7);
                    if (z7) {
                        if (!Character.isHighSurrogate(charAt)) {
                            return -1;
                        }
                        i8--;
                    } else if (!Character.isSurrogate(charAt)) {
                        i8--;
                    } else if (Character.isHighSurrogate(charAt)) {
                        return -1;
                    } else {
                        z7 = true;
                    }
                }
                return i7;
            }
        }

        static int findIndexForward(CharSequence charSequence, int i7, int i8) {
            int length = charSequence.length();
            if (i7 < 0 || length < i7 || i8 < 0) {
                return -1;
            }
            while (true) {
                boolean z7 = false;
                while (i8 != 0) {
                    if (i7 < length) {
                        char charAt = charSequence.charAt(i7);
                        if (z7) {
                            if (!Character.isLowSurrogate(charAt)) {
                                return -1;
                            }
                            i8--;
                            i7++;
                        } else if (!Character.isSurrogate(charAt)) {
                            i8--;
                            i7++;
                        } else if (Character.isLowSurrogate(charAt)) {
                            return -1;
                        } else {
                            i7++;
                            z7 = true;
                        }
                    } else if (z7) {
                        return -1;
                    } else {
                        return length;
                    }
                }
                return i7;
            }
        }
    }

    @AnyThread
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public static class DefaultGlyphChecker implements EmojiCompat.GlyphChecker {
        private static final int PAINT_TEXT_SIZE = 10;
        private static final ThreadLocal<StringBuilder> sStringBuilder = new ThreadLocal<>();
        private final TextPaint mTextPaint;

        DefaultGlyphChecker() {
            TextPaint textPaint = new TextPaint();
            this.mTextPaint = textPaint;
            textPaint.setTextSize(10.0f);
        }

        private static StringBuilder getStringBuilder() {
            ThreadLocal<StringBuilder> threadLocal = sStringBuilder;
            if (threadLocal.get() == null) {
                threadLocal.set(new StringBuilder());
            }
            return threadLocal.get();
        }

        @Override // androidx.emoji2.text.EmojiCompat.GlyphChecker
        public boolean hasGlyph(@NonNull CharSequence charSequence, int i7, int i8, int i9) {
            StringBuilder stringBuilder = getStringBuilder();
            stringBuilder.setLength(0);
            while (i7 < i8) {
                stringBuilder.append(charSequence.charAt(i7));
                i7++;
            }
            return PaintCompat.hasGlyph(this.mTextPaint, stringBuilder.toString());
        }
    }

    /* access modifiers changed from: package-private */
    public static final class ProcessorSm {
        private static final int STATE_DEFAULT = 1;
        private static final int STATE_WALKING = 2;
        private int mCurrentDepth;
        private MetadataRepo.Node mCurrentNode;
        private final int[] mEmojiAsDefaultStyleExceptions;
        private MetadataRepo.Node mFlushNode;
        private int mLastCodepoint;
        private final MetadataRepo.Node mRootNode;
        private int mState = 1;
        private final boolean mUseEmojiAsDefaultStyle;

        ProcessorSm(MetadataRepo.Node node, boolean z7, int[] iArr) {
            this.mRootNode = node;
            this.mCurrentNode = node;
            this.mUseEmojiAsDefaultStyle = z7;
            this.mEmojiAsDefaultStyleExceptions = iArr;
        }

        private static boolean isEmojiStyle(int i7) {
            return i7 == 65039;
        }

        private static boolean isTextStyle(int i7) {
            return i7 == 65038;
        }

        private int reset() {
            this.mState = 1;
            this.mCurrentNode = this.mRootNode;
            this.mCurrentDepth = 0;
            return 1;
        }

        private boolean shouldUseEmojiPresentationStyleForSingleCodepoint() {
            if (this.mCurrentNode.getData().isDefaultEmoji() || isEmojiStyle(this.mLastCodepoint)) {
                return true;
            }
            if (this.mUseEmojiAsDefaultStyle) {
                if (this.mEmojiAsDefaultStyleExceptions == null) {
                    return true;
                }
                if (Arrays.binarySearch(this.mEmojiAsDefaultStyleExceptions, this.mCurrentNode.getData().getCodepointAt(0)) < 0) {
                    return true;
                }
            }
            return false;
        }

        /* access modifiers changed from: package-private */
        public int check(int i7) {
            MetadataRepo.Node node = this.mCurrentNode.get(i7);
            int i8 = 2;
            if (this.mState == 2) {
                if (node != null) {
                    this.mCurrentNode = node;
                    this.mCurrentDepth++;
                } else if (!isTextStyle(i7)) {
                    if (!isEmojiStyle(i7)) {
                        if (this.mCurrentNode.getData() != null) {
                            i8 = 3;
                            if (this.mCurrentDepth != 1 || shouldUseEmojiPresentationStyleForSingleCodepoint()) {
                                this.mFlushNode = this.mCurrentNode;
                                reset();
                            }
                        }
                    }
                }
                this.mLastCodepoint = i7;
                return i8;
            } else if (node != null) {
                this.mState = 2;
                this.mCurrentNode = node;
                this.mCurrentDepth = 1;
                this.mLastCodepoint = i7;
                return i8;
            }
            i8 = reset();
            this.mLastCodepoint = i7;
            return i8;
        }

        /* access modifiers changed from: package-private */
        public EmojiMetadata getCurrentMetadata() {
            return this.mCurrentNode.getData();
        }

        /* access modifiers changed from: package-private */
        public EmojiMetadata getFlushMetadata() {
            return this.mFlushNode.getData();
        }

        /* access modifiers changed from: package-private */
        public boolean isInFlushableState() {
            return this.mState == 2 && this.mCurrentNode.getData() != null && (this.mCurrentDepth > 1 || shouldUseEmojiPresentationStyleForSingleCodepoint());
        }
    }

    EmojiProcessor(@NonNull MetadataRepo metadataRepo, @NonNull EmojiCompat.SpanFactory spanFactory, @NonNull EmojiCompat.GlyphChecker glyphChecker, boolean z7, @Nullable int[] iArr) {
        this.mSpanFactory = spanFactory;
        this.mMetadataRepo = metadataRepo;
        this.mGlyphChecker = glyphChecker;
        this.mUseEmojiAsDefaultStyle = z7;
        this.mEmojiAsDefaultStyleExceptions = iArr;
    }

    private void addEmoji(@NonNull Spannable spannable, EmojiMetadata emojiMetadata, int i7, int i8) {
        spannable.setSpan(this.mSpanFactory.createSpan(emojiMetadata), i7, i8, 33);
    }

    private static boolean delete(@NonNull Editable editable, @NonNull KeyEvent keyEvent, boolean z7) {
        EmojiSpan[] emojiSpanArr;
        if (hasModifiers(keyEvent)) {
            return false;
        }
        int selectionStart = Selection.getSelectionStart(editable);
        int selectionEnd = Selection.getSelectionEnd(editable);
        if (!hasInvalidSelection(selectionStart, selectionEnd) && (emojiSpanArr = (EmojiSpan[]) editable.getSpans(selectionStart, selectionEnd, EmojiSpan.class)) != null && emojiSpanArr.length > 0) {
            for (EmojiSpan emojiSpan : emojiSpanArr) {
                int spanStart = editable.getSpanStart(emojiSpan);
                int spanEnd = editable.getSpanEnd(emojiSpan);
                if ((z7 && spanStart == selectionStart) || ((!z7 && spanEnd == selectionStart) || (selectionStart > spanStart && selectionStart < spanEnd))) {
                    editable.delete(spanStart, spanEnd);
                    return true;
                }
            }
        }
        return false;
    }

    static boolean handleDeleteSurroundingText(@NonNull InputConnection inputConnection, @NonNull Editable editable, @IntRange(from = 0) int i7, @IntRange(from = 0) int i8, boolean z7) {
        int i9;
        int i10;
        if (editable != null && inputConnection != null && i7 >= 0 && i8 >= 0) {
            int selectionStart = Selection.getSelectionStart(editable);
            int selectionEnd = Selection.getSelectionEnd(editable);
            if (hasInvalidSelection(selectionStart, selectionEnd)) {
                return false;
            }
            if (z7) {
                i10 = CodepointIndexFinder.findIndexBackward(editable, selectionStart, Math.max(i7, 0));
                i9 = CodepointIndexFinder.findIndexForward(editable, selectionEnd, Math.max(i8, 0));
                if (i10 == -1 || i9 == -1) {
                    return false;
                }
            } else {
                i10 = Math.max(selectionStart - i7, 0);
                i9 = Math.min(selectionEnd + i8, editable.length());
            }
            EmojiSpan[] emojiSpanArr = (EmojiSpan[]) editable.getSpans(i10, i9, EmojiSpan.class);
            if (emojiSpanArr != null && emojiSpanArr.length > 0) {
                for (EmojiSpan emojiSpan : emojiSpanArr) {
                    int spanStart = editable.getSpanStart(emojiSpan);
                    int spanEnd = editable.getSpanEnd(emojiSpan);
                    i10 = Math.min(spanStart, i10);
                    i9 = Math.max(spanEnd, i9);
                }
                int max = Math.max(i10, 0);
                int min = Math.min(i9, editable.length());
                inputConnection.beginBatchEdit();
                editable.delete(max, min);
                inputConnection.endBatchEdit();
                return true;
            }
        }
        return false;
    }

    static boolean handleOnKeyDown(@NonNull Editable editable, int i7, @NonNull KeyEvent keyEvent) {
        if (!(i7 != 67 ? i7 != 112 ? false : delete(editable, keyEvent, true) : delete(editable, keyEvent, false))) {
            return false;
        }
        MetaKeyKeyListener.adjustMetaAfterKeypress(editable);
        return true;
    }

    private boolean hasGlyph(CharSequence charSequence, int i7, int i8, EmojiMetadata emojiMetadata) {
        if (emojiMetadata.getHasGlyph() == 0) {
            emojiMetadata.setHasGlyph(this.mGlyphChecker.hasGlyph(charSequence, i7, i8, emojiMetadata.getSdkAdded()));
        }
        return emojiMetadata.getHasGlyph() == 2;
    }

    private static boolean hasInvalidSelection(int i7, int i8) {
        return i7 == -1 || i8 == -1 || i7 != i8;
    }

    private static boolean hasModifiers(@NonNull KeyEvent keyEvent) {
        return !KeyEvent.metaStateHasNoModifiers(keyEvent.getMetaState());
    }

    /* access modifiers changed from: package-private */
    public EmojiMetadata getEmojiMetadata(@NonNull CharSequence charSequence) {
        ProcessorSm processorSm = new ProcessorSm(this.mMetadataRepo.getRootNode(), this.mUseEmojiAsDefaultStyle, this.mEmojiAsDefaultStyleExceptions);
        int length = charSequence.length();
        int i7 = 0;
        while (i7 < length) {
            int codePointAt = Character.codePointAt(charSequence, i7);
            if (processorSm.check(codePointAt) != 2) {
                return null;
            }
            i7 += Character.charCount(codePointAt);
        }
        if (processorSm.isInFlushableState()) {
            return processorSm.getCurrentMetadata();
        }
        return null;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:66:0x00f0 */
    /* JADX DEBUG: Multi-variable search result rejected for r11v0, resolved type: java.lang.CharSequence */
    /* JADX WARN: Multi-variable type inference failed */
    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0041 A[Catch:{ all -> 0x0113 }] */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x005d A[Catch:{ all -> 0x0113 }] */
    /* JADX WARNING: Removed duplicated region for block: B:75:0x010c  */
    public CharSequence process(@NonNull CharSequence charSequence, @IntRange(from = 0) int i7, @IntRange(from = 0) int i8, @IntRange(from = 0) int i9, boolean z7) {
        Spannable spannable;
        int i10;
        EmojiSpan[] emojiSpanArr;
        boolean z8 = charSequence instanceof SpannableBuilder;
        if (z8) {
            ((SpannableBuilder) charSequence).beginBatchEdit();
        }
        if (!z8) {
            try {
                if (!(charSequence instanceof Spannable)) {
                    spannable = (!(charSequence instanceof Spanned) || ((Spanned) charSequence).nextSpanTransition(i7 + -1, i8 + 1, EmojiSpan.class) > i8) ? null : new SpannableString(charSequence);
                    if (!(spannable == null || (emojiSpanArr = (EmojiSpan[]) spannable.getSpans(i7, i8, EmojiSpan.class)) == null || emojiSpanArr.length <= 0)) {
                        for (EmojiSpan emojiSpan : emojiSpanArr) {
                            int spanStart = spannable.getSpanStart(emojiSpan);
                            int spanEnd = spannable.getSpanEnd(emojiSpan);
                            if (spanStart != i8) {
                                spannable.removeSpan(emojiSpan);
                            }
                            i7 = Math.min(spanStart, i7);
                            i8 = Math.max(spanEnd, i8);
                        }
                    }
                    if (i7 != i8) {
                        if (i7 < charSequence.length()) {
                            if (!(i9 == Integer.MAX_VALUE || spannable == null)) {
                                i9 -= ((EmojiSpan[]) spannable.getSpans(0, spannable.length(), EmojiSpan.class)).length;
                            }
                            ProcessorSm processorSm = new ProcessorSm(this.mMetadataRepo.getRootNode(), this.mUseEmojiAsDefaultStyle, this.mEmojiAsDefaultStyleExceptions);
                            int codePointAt = Character.codePointAt(charSequence, i7);
                            int i11 = 0;
                            SpannableString spannableString = spannable;
                            loop1:
                            while (true) {
                                i10 = i7;
                                while (i7 < i8 && i11 < i9) {
                                    int check = processorSm.check(codePointAt);
                                    if (check == 1) {
                                        i10 += Character.charCount(Character.codePointAt(charSequence, i10));
                                        if (i10 < i8) {
                                            codePointAt = Character.codePointAt(charSequence, i10);
                                        }
                                        i7 = i10;
                                    } else if (check == 2) {
                                        i7 += Character.charCount(codePointAt);
                                        if (i7 < i8) {
                                            codePointAt = Character.codePointAt(charSequence, i7);
                                        }
                                    } else if (check == 3) {
                                        if (z7 || !hasGlyph(charSequence, i10, i7, processorSm.getFlushMetadata())) {
                                            if (spannableString == null) {
                                                spannableString = new SpannableString(charSequence);
                                            }
                                            addEmoji(spannableString, processorSm.getFlushMetadata(), i10, i7);
                                            i11++;
                                        }
                                    }
                                }
                            }
                            if (processorSm.isInFlushableState() && i11 < i9 && (z7 || !hasGlyph(charSequence, i10, i7, processorSm.getCurrentMetadata()))) {
                                if (spannableString == null) {
                                    spannableString = new SpannableString(charSequence);
                                }
                                addEmoji(spannableString, processorSm.getCurrentMetadata(), i10, i7);
                            }
                            if (spannableString == null) {
                                spannableString = charSequence;
                            }
                            if (z8) {
                                ((SpannableBuilder) charSequence).endBatchEdit();
                            }
                            return spannableString;
                        }
                    }
                    if (z8) {
                        ((SpannableBuilder) charSequence).endBatchEdit();
                    }
                    return charSequence;
                }
            } catch (Throwable th) {
                if (z8) {
                    ((SpannableBuilder) charSequence).endBatchEdit();
                }
                throw th;
            }
        }
        spannable = (Spannable) charSequence;
        while (r6 < r5) {
        }
        if (i7 != i8) {
        }
        if (z8) {
        }
        return charSequence;
    }
}
