package androidx.security.crypto;

import android.content.Context;
import androidx.annotation.NonNull;
import com.google.crypto.tink.h0;
import com.google.crypto.tink.integration.android.a;
import com.google.crypto.tink.integration.android.c;
import com.google.crypto.tink.o;
import com.google.crypto.tink.streamingaead.b;
import com.google.crypto.tink.streamingaead.f;
import java.io.File;
import java.io.FileDescriptor;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.channels.FileChannel;
import java.nio.charset.StandardCharsets;
import java.security.GeneralSecurityException;

public final class EncryptedFile {
    private static final String KEYSET_ALIAS = "__androidx_security_crypto_encrypted_file_keyset__";
    private static final String KEYSET_PREF_NAME = "__androidx_security_crypto_encrypted_file_pref__";
    final Context mContext;
    final File mFile;
    final String mMasterKeyAlias;
    final h0 mStreamingAead;

    public static final class Builder {
        final Context mContext;
        File mFile;
        final FileEncryptionScheme mFileEncryptionScheme;
        String mKeysetAlias = EncryptedFile.KEYSET_ALIAS;
        String mKeysetPrefName = EncryptedFile.KEYSET_PREF_NAME;
        final String mMasterKeyAlias;

        public Builder(@NonNull File file, @NonNull Context context, @NonNull String str, @NonNull FileEncryptionScheme fileEncryptionScheme) {
            this.mFile = file;
            this.mFileEncryptionScheme = fileEncryptionScheme;
            this.mContext = context;
            this.mMasterKeyAlias = str;
        }

        @NonNull
        public EncryptedFile build() throws GeneralSecurityException, IOException {
            f.b();
            a.b m7 = new a.b().j(this.mFileEncryptionScheme.getKeyTemplate()).m(this.mContext, this.mKeysetAlias, this.mKeysetPrefName);
            return new EncryptedFile(this.mFile, this.mKeysetAlias, (h0) m7.l(c.f12498e + this.mMasterKeyAlias).d().k().m(h0.class), this.mContext);
        }

        @NonNull
        public Builder setKeysetAlias(@NonNull String str) {
            this.mKeysetAlias = str;
            return this;
        }

        @NonNull
        public Builder setKeysetPrefName(@NonNull String str) {
            this.mKeysetPrefName = str;
            return this;
        }
    }

    private static final class EncryptedFileInputStream extends FileInputStream {
        private final InputStream mEncryptedInputStream;

        EncryptedFileInputStream(FileDescriptor fileDescriptor, InputStream inputStream) {
            super(fileDescriptor);
            this.mEncryptedInputStream = inputStream;
        }

        @Override // java.io.FileInputStream, java.io.InputStream
        public int available() throws IOException {
            return this.mEncryptedInputStream.available();
        }

        @Override // java.io.Closeable, java.io.FileInputStream, java.lang.AutoCloseable, java.io.InputStream
        public void close() throws IOException {
            this.mEncryptedInputStream.close();
        }

        public FileChannel getChannel() {
            throw new UnsupportedOperationException("For encrypted files, please open the relevant FileInput/FileOutputStream.");
        }

        public synchronized void mark(int i7) {
            this.mEncryptedInputStream.mark(i7);
        }

        public boolean markSupported() {
            return this.mEncryptedInputStream.markSupported();
        }

        @Override // java.io.FileInputStream, java.io.InputStream
        public int read() throws IOException {
            return this.mEncryptedInputStream.read();
        }

        @Override // java.io.InputStream
        public synchronized void reset() throws IOException {
            this.mEncryptedInputStream.reset();
        }

        @Override // java.io.FileInputStream, java.io.InputStream
        public long skip(long j7) throws IOException {
            return this.mEncryptedInputStream.skip(j7);
        }

        @Override // java.io.FileInputStream, java.io.InputStream
        public int read(@NonNull byte[] bArr) throws IOException {
            return this.mEncryptedInputStream.read(bArr);
        }

        @Override // java.io.FileInputStream, java.io.InputStream
        public int read(@NonNull byte[] bArr, int i7, int i8) throws IOException {
            return this.mEncryptedInputStream.read(bArr, i7, i8);
        }
    }

    private static final class EncryptedFileOutputStream extends FileOutputStream {
        private final OutputStream mEncryptedOutputStream;

        EncryptedFileOutputStream(FileDescriptor fileDescriptor, OutputStream outputStream) {
            super(fileDescriptor);
            this.mEncryptedOutputStream = outputStream;
        }

        @Override // java.io.OutputStream, java.io.Closeable, java.io.FileOutputStream, java.lang.AutoCloseable
        public void close() throws IOException {
            this.mEncryptedOutputStream.close();
        }

        @Override // java.io.OutputStream, java.io.Flushable
        public void flush() throws IOException {
            this.mEncryptedOutputStream.flush();
        }

        @NonNull
        public FileChannel getChannel() {
            throw new UnsupportedOperationException("For encrypted files, please open the relevant FileInput/FileOutputStream.");
        }

        @Override // java.io.OutputStream, java.io.FileOutputStream
        public void write(int i7) throws IOException {
            this.mEncryptedOutputStream.write(i7);
        }

        @Override // java.io.OutputStream, java.io.FileOutputStream
        public void write(@NonNull byte[] bArr) throws IOException {
            this.mEncryptedOutputStream.write(bArr);
        }

        @Override // java.io.OutputStream, java.io.FileOutputStream
        public void write(@NonNull byte[] bArr, int i7, int i8) throws IOException {
            this.mEncryptedOutputStream.write(bArr, i7, i8);
        }
    }

    public enum FileEncryptionScheme {
        AES256_GCM_HKDF_4KB(b.o());
        
        private final o mStreamingAeadKeyTemplate;

        private FileEncryptionScheme(o oVar) {
            this.mStreamingAeadKeyTemplate = oVar;
        }

        /* access modifiers changed from: package-private */
        public o getKeyTemplate() {
            return this.mStreamingAeadKeyTemplate;
        }
    }

    EncryptedFile(@NonNull File file, @NonNull String str, @NonNull h0 h0Var, @NonNull Context context) {
        this.mFile = file;
        this.mContext = context;
        this.mMasterKeyAlias = str;
        this.mStreamingAead = h0Var;
    }

    @NonNull
    public FileInputStream openFileInput() throws GeneralSecurityException, IOException {
        if (this.mFile.exists()) {
            FileInputStream fileInputStream = new FileInputStream(this.mFile);
            return new EncryptedFileInputStream(fileInputStream.getFD(), this.mStreamingAead.e(fileInputStream, this.mFile.getName().getBytes(StandardCharsets.UTF_8)));
        }
        throw new IOException("file doesn't exist: " + this.mFile.getName());
    }

    @NonNull
    public FileOutputStream openFileOutput() throws GeneralSecurityException, IOException {
        if (!this.mFile.exists()) {
            FileOutputStream fileOutputStream = new FileOutputStream(this.mFile);
            return new EncryptedFileOutputStream(fileOutputStream.getFD(), this.mStreamingAead.b(fileOutputStream, this.mFile.getName().getBytes(StandardCharsets.UTF_8)));
        }
        throw new IOException("output file already exists, please use a new file: " + this.mFile.getName());
    }
}
