package androidx.versionedparcelable;

import android.os.BadParcelableException;
import android.os.Bundle;
import android.os.IBinder;
import android.os.IInterface;
import android.os.NetworkOnMainThreadException;
import android.os.Parcelable;
import android.util.Size;
import android.util.SizeF;
import android.util.SparseBooleanArray;
import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.collection.ArrayMap;
import androidx.collection.ArraySet;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.ObjectStreamClass;
import java.io.Serializable;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
public abstract class VersionedParcel {
    private static final int EX_BAD_PARCELABLE = -2;
    private static final int EX_ILLEGAL_ARGUMENT = -3;
    private static final int EX_ILLEGAL_STATE = -5;
    private static final int EX_NETWORK_MAIN_THREAD = -6;
    private static final int EX_NULL_POINTER = -4;
    private static final int EX_PARCELABLE = -9;
    private static final int EX_SECURITY = -1;
    private static final int EX_UNSUPPORTED_OPERATION = -7;
    private static final String TAG = "VersionedParcel";
    private static final int TYPE_BINDER = 5;
    private static final int TYPE_FLOAT = 8;
    private static final int TYPE_INTEGER = 7;
    private static final int TYPE_PARCELABLE = 2;
    private static final int TYPE_SERIALIZABLE = 3;
    private static final int TYPE_STRING = 4;
    private static final int TYPE_VERSIONED_PARCELABLE = 1;
    protected final ArrayMap<String, Class> mParcelizerCache;
    protected final ArrayMap<String, Method> mReadCache;
    protected final ArrayMap<String, Method> mWriteCache;

    public static class ParcelException extends RuntimeException {
        public ParcelException(Throwable th) {
            super(th);
        }
    }

    public VersionedParcel(ArrayMap<String, Method> arrayMap, ArrayMap<String, Method> arrayMap2, ArrayMap<String, Class> arrayMap3) {
        this.mReadCache = arrayMap;
        this.mWriteCache = arrayMap2;
        this.mParcelizerCache = arrayMap3;
    }

    private Exception createException(int i7, String str) {
        switch (i7) {
            case EX_PARCELABLE /*{ENCODED_INT: -9}*/:
                return (Exception) readParcelable();
            case -8:
            default:
                return new RuntimeException("Unknown exception code: " + i7 + " msg " + str);
            case EX_UNSUPPORTED_OPERATION /*{ENCODED_INT: -7}*/:
                return new UnsupportedOperationException(str);
            case EX_NETWORK_MAIN_THREAD /*{ENCODED_INT: -6}*/:
                return new NetworkOnMainThreadException();
            case EX_ILLEGAL_STATE /*{ENCODED_INT: -5}*/:
                return new IllegalStateException(str);
            case -4:
                return new NullPointerException(str);
            case -3:
                return new IllegalArgumentException(str);
            case -2:
                return new BadParcelableException(str);
            case -1:
                return new SecurityException(str);
        }
    }

    private Class findParcelClass(Class<? extends VersionedParcelable> cls) throws ClassNotFoundException {
        Class cls2 = this.mParcelizerCache.get(cls.getName());
        if (cls2 != null) {
            return cls2;
        }
        Class<?> cls3 = Class.forName(String.format("%s.%sParcelizer", cls.getPackage().getName(), cls.getSimpleName()), false, cls.getClassLoader());
        this.mParcelizerCache.put(cls.getName(), cls3);
        return cls3;
    }

    private Method getReadMethod(String str) throws IllegalAccessException, NoSuchMethodException, ClassNotFoundException {
        Method method = this.mReadCache.get(str);
        if (method != null) {
            return method;
        }
        System.currentTimeMillis();
        Method declaredMethod = Class.forName(str, true, VersionedParcel.class.getClassLoader()).getDeclaredMethod("read", VersionedParcel.class);
        this.mReadCache.put(str, declaredMethod);
        return declaredMethod;
    }

    @NonNull
    protected static Throwable getRootCause(@NonNull Throwable th) {
        while (th.getCause() != null) {
            th = th.getCause();
        }
        return th;
    }

    private <T> int getType(T t7) {
        if (t7 instanceof String) {
            return 4;
        }
        if (t7 instanceof Parcelable) {
            return 2;
        }
        if (t7 instanceof VersionedParcelable) {
            return 1;
        }
        if (t7 instanceof Serializable) {
            return 3;
        }
        if (t7 instanceof IBinder) {
            return 5;
        }
        if (t7 instanceof Integer) {
            return 7;
        }
        if (t7 instanceof Float) {
            return 8;
        }
        throw new IllegalArgumentException(t7.getClass().getName() + " cannot be VersionedParcelled");
    }

    private Method getWriteMethod(Class cls) throws IllegalAccessException, NoSuchMethodException, ClassNotFoundException {
        Method method = this.mWriteCache.get(cls.getName());
        if (method != null) {
            return method;
        }
        Class findParcelClass = findParcelClass(cls);
        System.currentTimeMillis();
        Method declaredMethod = findParcelClass.getDeclaredMethod("write", cls, VersionedParcel.class);
        this.mWriteCache.put(cls.getName(), declaredMethod);
        return declaredMethod;
    }

    private <T, S extends Collection<T>> S readCollection(S s7) {
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        if (readInt != 0) {
            int readInt2 = readInt();
            if (readInt < 0) {
                return null;
            }
            if (readInt2 == 1) {
                while (readInt > 0) {
                    s7.add(readVersionedParcelable());
                    readInt--;
                }
            } else if (readInt2 == 2) {
                while (readInt > 0) {
                    s7.add(readParcelable());
                    readInt--;
                }
            } else if (readInt2 == 3) {
                while (readInt > 0) {
                    s7.add(readSerializable());
                    readInt--;
                }
            } else if (readInt2 == 4) {
                while (readInt > 0) {
                    s7.add(readString());
                    readInt--;
                }
            } else if (readInt2 == 5) {
                while (readInt > 0) {
                    s7.add(readStrongBinder());
                    readInt--;
                }
            }
        }
        return s7;
    }

    private Exception readException(int i7, String str) {
        return createException(i7, str);
    }

    private int readExceptionCode() {
        return readInt();
    }

    private <T> void writeCollection(Collection<T> collection) {
        if (collection == null) {
            writeInt(-1);
            return;
        }
        int size = collection.size();
        writeInt(size);
        if (size > 0) {
            int type = getType(collection.iterator().next());
            writeInt(type);
            switch (type) {
                case 1:
                    for (T t7 : collection) {
                        writeVersionedParcelable(t7);
                    }
                    return;
                case 2:
                    for (T t8 : collection) {
                        writeParcelable(t8);
                    }
                    return;
                case 3:
                    for (T t9 : collection) {
                        writeSerializable(t9);
                    }
                    return;
                case 4:
                    for (T t10 : collection) {
                        writeString(t10);
                    }
                    return;
                case 5:
                    for (T t11 : collection) {
                        writeStrongBinder(t11);
                    }
                    return;
                case 6:
                default:
                    return;
                case 7:
                    for (T t12 : collection) {
                        writeInt(t12.intValue());
                    }
                    return;
                case 8:
                    for (T t13 : collection) {
                        writeFloat(t13.floatValue());
                    }
                    return;
            }
        }
    }

    private void writeSerializable(Serializable serializable) {
        if (serializable == null) {
            writeString(null);
            return;
        }
        String name = serializable.getClass().getName();
        writeString(name);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            ObjectOutputStream objectOutputStream = new ObjectOutputStream(byteArrayOutputStream);
            objectOutputStream.writeObject(serializable);
            objectOutputStream.close();
            writeByteArray(byteArrayOutputStream.toByteArray());
        } catch (IOException e7) {
            throw new RuntimeException("VersionedParcelable encountered IOException writing serializable object (name = " + name + ")", e7);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: androidx.versionedparcelable.VersionedParcel */
    /* JADX WARN: Multi-variable type inference failed */
    private void writeVersionedParcelableCreator(VersionedParcelable versionedParcelable) {
        try {
            writeString(findParcelClass(versionedParcelable.getClass()).getName());
        } catch (ClassNotFoundException e7) {
            throw new RuntimeException(versionedParcelable.getClass().getSimpleName() + " does not have a Parcelizer", e7);
        }
    }

    /* access modifiers changed from: protected */
    public abstract void closeField();

    /* access modifiers changed from: protected */
    public abstract VersionedParcel createSubParcel();

    public boolean isStream() {
        return false;
    }

    /* access modifiers changed from: protected */
    public <T> T[] readArray(T[] tArr) {
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        ArrayList arrayList = new ArrayList(readInt);
        if (readInt != 0) {
            int readInt2 = readInt();
            if (readInt < 0) {
                return null;
            }
            if (readInt2 == 1) {
                while (readInt > 0) {
                    arrayList.add(readVersionedParcelable());
                    readInt--;
                }
            } else if (readInt2 == 2) {
                while (readInt > 0) {
                    arrayList.add(readParcelable());
                    readInt--;
                }
            } else if (readInt2 == 3) {
                while (readInt > 0) {
                    arrayList.add(readSerializable());
                    readInt--;
                }
            } else if (readInt2 == 4) {
                while (readInt > 0) {
                    arrayList.add(readString());
                    readInt--;
                }
            } else if (readInt2 == 5) {
                while (readInt > 0) {
                    arrayList.add(readStrongBinder());
                    readInt--;
                }
            }
        }
        return (T[]) arrayList.toArray(tArr);
    }

    /* access modifiers changed from: protected */
    public abstract boolean readBoolean();

    public boolean readBoolean(boolean z7, int i7) {
        return !readField(i7) ? z7 : readBoolean();
    }

    /* access modifiers changed from: protected */
    public boolean[] readBooleanArray() {
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        boolean[] zArr = new boolean[readInt];
        for (int i7 = 0; i7 < readInt; i7++) {
            zArr[i7] = readInt() != 0;
        }
        return zArr;
    }

    /* access modifiers changed from: protected */
    public abstract Bundle readBundle();

    public Bundle readBundle(Bundle bundle, int i7) {
        return !readField(i7) ? bundle : readBundle();
    }

    public byte readByte(byte b7, int i7) {
        return !readField(i7) ? b7 : (byte) (readInt() & 255);
    }

    /* access modifiers changed from: protected */
    public abstract byte[] readByteArray();

    public byte[] readByteArray(byte[] bArr, int i7) {
        return !readField(i7) ? bArr : readByteArray();
    }

    public char[] readCharArray(char[] cArr, int i7) {
        if (!readField(i7)) {
            return cArr;
        }
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        char[] cArr2 = new char[readInt];
        for (int i8 = 0; i8 < readInt; i8++) {
            cArr2[i8] = (char) readInt();
        }
        return cArr2;
    }

    /* access modifiers changed from: protected */
    public abstract CharSequence readCharSequence();

    public CharSequence readCharSequence(CharSequence charSequence, int i7) {
        return !readField(i7) ? charSequence : readCharSequence();
    }

    /* access modifiers changed from: protected */
    public abstract double readDouble();

    public double readDouble(double d7, int i7) {
        return !readField(i7) ? d7 : readDouble();
    }

    /* access modifiers changed from: protected */
    public double[] readDoubleArray() {
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        double[] dArr = new double[readInt];
        for (int i7 = 0; i7 < readInt; i7++) {
            dArr[i7] = readDouble();
        }
        return dArr;
    }

    /* access modifiers changed from: protected */
    public abstract boolean readField(int i7);

    /* access modifiers changed from: protected */
    public abstract float readFloat();

    public float readFloat(float f7, int i7) {
        return !readField(i7) ? f7 : readFloat();
    }

    /* access modifiers changed from: protected */
    public float[] readFloatArray() {
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        float[] fArr = new float[readInt];
        for (int i7 = 0; i7 < readInt; i7++) {
            fArr[i7] = readFloat();
        }
        return fArr;
    }

    /* access modifiers changed from: protected */
    public <T extends VersionedParcelable> T readFromParcel(String str, VersionedParcel versionedParcel) {
        try {
            return (T) ((VersionedParcelable) getReadMethod(str).invoke(null, versionedParcel));
        } catch (IllegalAccessException e7) {
            throw new RuntimeException("VersionedParcel encountered IllegalAccessException", e7);
        } catch (InvocationTargetException e8) {
            if (e8.getCause() instanceof RuntimeException) {
                throw ((RuntimeException) e8.getCause());
            }
            throw new RuntimeException("VersionedParcel encountered InvocationTargetException", e8);
        } catch (NoSuchMethodException e9) {
            throw new RuntimeException("VersionedParcel encountered NoSuchMethodException", e9);
        } catch (ClassNotFoundException e10) {
            throw new RuntimeException("VersionedParcel encountered ClassNotFoundException", e10);
        }
    }

    /* access modifiers changed from: protected */
    public abstract int readInt();

    public int readInt(int i7, int i8) {
        return !readField(i8) ? i7 : readInt();
    }

    /* access modifiers changed from: protected */
    public int[] readIntArray() {
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        int[] iArr = new int[readInt];
        for (int i7 = 0; i7 < readInt; i7++) {
            iArr[i7] = readInt();
        }
        return iArr;
    }

    public <T> List<T> readList(List<T> list, int i7) {
        return !readField(i7) ? list : (List) readCollection(new ArrayList());
    }

    /* access modifiers changed from: protected */
    public abstract long readLong();

    public long readLong(long j7, int i7) {
        return !readField(i7) ? j7 : readLong();
    }

    /* access modifiers changed from: protected */
    public long[] readLongArray() {
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        long[] jArr = new long[readInt];
        for (int i7 = 0; i7 < readInt; i7++) {
            jArr[i7] = readLong();
        }
        return jArr;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r6v2, resolved type: androidx.collection.ArrayMap */
    /* JADX WARN: Multi-variable type inference failed */
    public <K, V> Map<K, V> readMap(Map<K, V> map, int i7) {
        if (!readField(i7)) {
            return map;
        }
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        ArrayMap arrayMap = new ArrayMap();
        if (readInt == 0) {
            return arrayMap;
        }
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        readCollection(arrayList);
        readCollection(arrayList2);
        for (int i8 = 0; i8 < readInt; i8++) {
            arrayMap.put(arrayList.get(i8), arrayList2.get(i8));
        }
        return arrayMap;
    }

    /* access modifiers changed from: protected */
    public abstract <T extends Parcelable> T readParcelable();

    public <T extends Parcelable> T readParcelable(T t7, int i7) {
        return !readField(i7) ? t7 : (T) readParcelable();
    }

    /* access modifiers changed from: protected */
    public Serializable readSerializable() {
        String readString = readString();
        if (readString == null) {
            return null;
        }
        try {
            return (Serializable) new ObjectInputStream(new ByteArrayInputStream(readByteArray())) {
                /* class androidx.versionedparcelable.VersionedParcel.AnonymousClass1 */

                /* access modifiers changed from: protected */
                @Override // java.io.ObjectInputStream
                public Class<?> resolveClass(ObjectStreamClass objectStreamClass) throws IOException, ClassNotFoundException {
                    Class<?> cls = Class.forName(objectStreamClass.getName(), false, getClass().getClassLoader());
                    return cls != null ? cls : super.resolveClass(objectStreamClass);
                }
            }.readObject();
        } catch (IOException e7) {
            throw new RuntimeException("VersionedParcelable encountered IOException reading a Serializable object (name = " + readString + ")", e7);
        } catch (ClassNotFoundException e8) {
            throw new RuntimeException("VersionedParcelable encountered ClassNotFoundException reading a Serializable object (name = " + readString + ")", e8);
        }
    }

    public <T> Set<T> readSet(Set<T> set, int i7) {
        return !readField(i7) ? set : (Set) readCollection(new ArraySet());
    }

    @RequiresApi(api = 21)
    public Size readSize(Size size, int i7) {
        if (!readField(i7)) {
            return size;
        }
        if (readBoolean()) {
            return new Size(readInt(), readInt());
        }
        return null;
    }

    @RequiresApi(api = 21)
    public SizeF readSizeF(SizeF sizeF, int i7) {
        if (!readField(i7)) {
            return sizeF;
        }
        if (readBoolean()) {
            return new SizeF(readFloat(), readFloat());
        }
        return null;
    }

    public SparseBooleanArray readSparseBooleanArray(SparseBooleanArray sparseBooleanArray, int i7) {
        if (!readField(i7)) {
            return sparseBooleanArray;
        }
        int readInt = readInt();
        if (readInt < 0) {
            return null;
        }
        SparseBooleanArray sparseBooleanArray2 = new SparseBooleanArray(readInt);
        for (int i8 = 0; i8 < readInt; i8++) {
            sparseBooleanArray2.put(readInt(), readBoolean());
        }
        return sparseBooleanArray2;
    }

    /* access modifiers changed from: protected */
    public abstract String readString();

    public String readString(String str, int i7) {
        return !readField(i7) ? str : readString();
    }

    /* access modifiers changed from: protected */
    public abstract IBinder readStrongBinder();

    public IBinder readStrongBinder(IBinder iBinder, int i7) {
        return !readField(i7) ? iBinder : readStrongBinder();
    }

    /* access modifiers changed from: protected */
    public <T extends VersionedParcelable> T readVersionedParcelable() {
        String readString = readString();
        if (readString == null) {
            return null;
        }
        return (T) readFromParcel(readString, createSubParcel());
    }

    /* access modifiers changed from: protected */
    public abstract void setOutputField(int i7);

    public void setSerializationFlags(boolean z7, boolean z8) {
    }

    /* access modifiers changed from: protected */
    public <T> void writeArray(T[] tArr) {
        if (tArr == null) {
            writeInt(-1);
            return;
        }
        int length = tArr.length;
        writeInt(length);
        if (length > 0) {
            int i7 = 0;
            int type = getType(tArr[0]);
            writeInt(type);
            if (type == 1) {
                while (i7 < length) {
                    writeVersionedParcelable(tArr[i7]);
                    i7++;
                }
            } else if (type == 2) {
                while (i7 < length) {
                    writeParcelable(tArr[i7]);
                    i7++;
                }
            } else if (type == 3) {
                while (i7 < length) {
                    writeSerializable(tArr[i7]);
                    i7++;
                }
            } else if (type == 4) {
                while (i7 < length) {
                    writeString(tArr[i7]);
                    i7++;
                }
            } else if (type == 5) {
                while (i7 < length) {
                    writeStrongBinder(tArr[i7]);
                    i7++;
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public abstract void writeBoolean(boolean z7);

    public void writeBoolean(boolean z7, int i7) {
        setOutputField(i7);
        writeBoolean(z7);
    }

    /* access modifiers changed from: protected */
    public void writeBooleanArray(boolean[] zArr) {
        if (zArr != null) {
            int length = zArr.length;
            writeInt(length);
            for (boolean z7 : zArr) {
                writeInt(z7 ? 1 : 0);
            }
            return;
        }
        writeInt(-1);
    }

    /* access modifiers changed from: protected */
    public abstract void writeBundle(Bundle bundle);

    public void writeBundle(Bundle bundle, int i7) {
        setOutputField(i7);
        writeBundle(bundle);
    }

    public void writeByte(byte b7, int i7) {
        setOutputField(i7);
        writeInt(b7);
    }

    /* access modifiers changed from: protected */
    public abstract void writeByteArray(byte[] bArr);

    public void writeByteArray(byte[] bArr, int i7) {
        setOutputField(i7);
        writeByteArray(bArr);
    }

    /* access modifiers changed from: protected */
    public abstract void writeByteArray(byte[] bArr, int i7, int i8);

    public void writeCharArray(char[] cArr, int i7) {
        setOutputField(i7);
        if (cArr != null) {
            int length = cArr.length;
            writeInt(length);
            for (char c7 : cArr) {
                writeInt(c7);
            }
            return;
        }
        writeInt(-1);
    }

    /* access modifiers changed from: protected */
    public abstract void writeCharSequence(CharSequence charSequence);

    public void writeCharSequence(CharSequence charSequence, int i7) {
        setOutputField(i7);
        writeCharSequence(charSequence);
    }

    /* access modifiers changed from: protected */
    public abstract void writeDouble(double d7);

    public void writeDouble(double d7, int i7) {
        setOutputField(i7);
        writeDouble(d7);
    }

    /* access modifiers changed from: protected */
    public void writeDoubleArray(double[] dArr) {
        if (dArr != null) {
            int length = dArr.length;
            writeInt(length);
            for (double d7 : dArr) {
                writeDouble(d7);
            }
            return;
        }
        writeInt(-1);
    }

    public void writeException(Exception exc, int i7) {
        setOutputField(i7);
        if (exc == null) {
            writeNoException();
            return;
        }
        int i8 = (!(exc instanceof Parcelable) || exc.getClass().getClassLoader() != Parcelable.class.getClassLoader()) ? exc instanceof SecurityException ? -1 : exc instanceof BadParcelableException ? -2 : exc instanceof IllegalArgumentException ? -3 : exc instanceof NullPointerException ? -4 : exc instanceof IllegalStateException ? EX_ILLEGAL_STATE : exc instanceof NetworkOnMainThreadException ? EX_NETWORK_MAIN_THREAD : exc instanceof UnsupportedOperationException ? EX_UNSUPPORTED_OPERATION : 0 : EX_PARCELABLE;
        writeInt(i8);
        if (i8 != 0) {
            writeString(exc.getMessage());
            if (i8 == EX_PARCELABLE) {
                writeParcelable((Parcelable) exc);
            }
        } else if (exc instanceof RuntimeException) {
            throw ((RuntimeException) exc);
        } else {
            throw new RuntimeException(exc);
        }
    }

    /* access modifiers changed from: protected */
    public abstract void writeFloat(float f7);

    public void writeFloat(float f7, int i7) {
        setOutputField(i7);
        writeFloat(f7);
    }

    /* access modifiers changed from: protected */
    public void writeFloatArray(float[] fArr) {
        if (fArr != null) {
            int length = fArr.length;
            writeInt(length);
            for (float f7 : fArr) {
                writeFloat(f7);
            }
            return;
        }
        writeInt(-1);
    }

    /* access modifiers changed from: protected */
    public abstract void writeInt(int i7);

    public void writeInt(int i7, int i8) {
        setOutputField(i8);
        writeInt(i7);
    }

    /* access modifiers changed from: protected */
    public void writeIntArray(int[] iArr) {
        if (iArr != null) {
            int length = iArr.length;
            writeInt(length);
            for (int i7 : iArr) {
                writeInt(i7);
            }
            return;
        }
        writeInt(-1);
    }

    public <T> void writeList(List<T> list, int i7) {
        writeCollection(list, i7);
    }

    /* access modifiers changed from: protected */
    public abstract void writeLong(long j7);

    public void writeLong(long j7, int i7) {
        setOutputField(i7);
        writeLong(j7);
    }

    /* access modifiers changed from: protected */
    public void writeLongArray(long[] jArr) {
        if (jArr != null) {
            int length = jArr.length;
            writeInt(length);
            for (long j7 : jArr) {
                writeLong(j7);
            }
            return;
        }
        writeInt(-1);
    }

    public <K, V> void writeMap(Map<K, V> map, int i7) {
        setOutputField(i7);
        if (map == null) {
            writeInt(-1);
            return;
        }
        int size = map.size();
        writeInt(size);
        if (size != 0) {
            ArrayList arrayList = new ArrayList();
            ArrayList arrayList2 = new ArrayList();
            for (Map.Entry<K, V> entry : map.entrySet()) {
                arrayList.add(entry.getKey());
                arrayList2.add(entry.getValue());
            }
            writeCollection(arrayList);
            writeCollection(arrayList2);
        }
    }

    /* access modifiers changed from: protected */
    public void writeNoException() {
        writeInt(0);
    }

    /* access modifiers changed from: protected */
    public abstract void writeParcelable(Parcelable parcelable);

    public void writeParcelable(Parcelable parcelable, int i7) {
        setOutputField(i7);
        writeParcelable(parcelable);
    }

    public <T> void writeSet(Set<T> set, int i7) {
        writeCollection(set, i7);
    }

    @RequiresApi(api = 21)
    public void writeSize(Size size, int i7) {
        setOutputField(i7);
        writeBoolean(size != null);
        if (size != null) {
            writeInt(size.getWidth());
            writeInt(size.getHeight());
        }
    }

    @RequiresApi(api = 21)
    public void writeSizeF(SizeF sizeF, int i7) {
        setOutputField(i7);
        writeBoolean(sizeF != null);
        if (sizeF != null) {
            writeFloat(sizeF.getWidth());
            writeFloat(sizeF.getHeight());
        }
    }

    public void writeSparseBooleanArray(SparseBooleanArray sparseBooleanArray, int i7) {
        setOutputField(i7);
        if (sparseBooleanArray == null) {
            writeInt(-1);
            return;
        }
        int size = sparseBooleanArray.size();
        writeInt(size);
        for (int i8 = 0; i8 < size; i8++) {
            writeInt(sparseBooleanArray.keyAt(i8));
            writeBoolean(sparseBooleanArray.valueAt(i8));
        }
    }

    /* access modifiers changed from: protected */
    public abstract void writeString(String str);

    public void writeString(String str, int i7) {
        setOutputField(i7);
        writeString(str);
    }

    /* access modifiers changed from: protected */
    public abstract void writeStrongBinder(IBinder iBinder);

    public void writeStrongBinder(IBinder iBinder, int i7) {
        setOutputField(i7);
        writeStrongBinder(iBinder);
    }

    /* access modifiers changed from: protected */
    public abstract void writeStrongInterface(IInterface iInterface);

    public void writeStrongInterface(IInterface iInterface, int i7) {
        setOutputField(i7);
        writeStrongInterface(iInterface);
    }

    /* access modifiers changed from: protected */
    public <T extends VersionedParcelable> void writeToParcel(T t7, VersionedParcel versionedParcel) {
        try {
            getWriteMethod(t7.getClass()).invoke(null, t7, versionedParcel);
        } catch (IllegalAccessException e7) {
            throw new RuntimeException("VersionedParcel encountered IllegalAccessException", e7);
        } catch (InvocationTargetException e8) {
            if (e8.getCause() instanceof RuntimeException) {
                throw ((RuntimeException) e8.getCause());
            }
            throw new RuntimeException("VersionedParcel encountered InvocationTargetException", e8);
        } catch (NoSuchMethodException e9) {
            throw new RuntimeException("VersionedParcel encountered NoSuchMethodException", e9);
        } catch (ClassNotFoundException e10) {
            throw new RuntimeException("VersionedParcel encountered ClassNotFoundException", e10);
        }
    }

    /* access modifiers changed from: protected */
    public void writeVersionedParcelable(VersionedParcelable versionedParcelable) {
        if (versionedParcelable == null) {
            writeString(null);
            return;
        }
        writeVersionedParcelableCreator(versionedParcelable);
        VersionedParcel createSubParcel = createSubParcel();
        writeToParcel(versionedParcelable, createSubParcel);
        createSubParcel.closeField();
    }

    private <T> void writeCollection(Collection<T> collection, int i7) {
        setOutputField(i7);
        writeCollection(collection);
    }

    public <T> T[] readArray(T[] tArr, int i7) {
        return !readField(i7) ? tArr : (T[]) readArray(tArr);
    }

    public boolean[] readBooleanArray(boolean[] zArr, int i7) {
        return !readField(i7) ? zArr : readBooleanArray();
    }

    public double[] readDoubleArray(double[] dArr, int i7) {
        return !readField(i7) ? dArr : readDoubleArray();
    }

    public Exception readException(Exception exc, int i7) {
        int readExceptionCode;
        return (readField(i7) && (readExceptionCode = readExceptionCode()) != 0) ? readException(readExceptionCode, readString()) : exc;
    }

    public float[] readFloatArray(float[] fArr, int i7) {
        return !readField(i7) ? fArr : readFloatArray();
    }

    public int[] readIntArray(int[] iArr, int i7) {
        return !readField(i7) ? iArr : readIntArray();
    }

    public long[] readLongArray(long[] jArr, int i7) {
        return !readField(i7) ? jArr : readLongArray();
    }

    public <T extends VersionedParcelable> T readVersionedParcelable(T t7, int i7) {
        return !readField(i7) ? t7 : (T) readVersionedParcelable();
    }

    public <T> void writeArray(T[] tArr, int i7) {
        setOutputField(i7);
        writeArray(tArr);
    }

    public void writeBooleanArray(boolean[] zArr, int i7) {
        setOutputField(i7);
        writeBooleanArray(zArr);
    }

    public void writeByteArray(byte[] bArr, int i7, int i8, int i9) {
        setOutputField(i9);
        writeByteArray(bArr, i7, i8);
    }

    public void writeDoubleArray(double[] dArr, int i7) {
        setOutputField(i7);
        writeDoubleArray(dArr);
    }

    public void writeFloatArray(float[] fArr, int i7) {
        setOutputField(i7);
        writeFloatArray(fArr);
    }

    public void writeIntArray(int[] iArr, int i7) {
        setOutputField(i7);
        writeIntArray(iArr);
    }

    public void writeLongArray(long[] jArr, int i7) {
        setOutputField(i7);
        writeLongArray(jArr);
    }

    public void writeSerializable(Serializable serializable, int i7) {
        setOutputField(i7);
        writeSerializable(serializable);
    }

    public void writeVersionedParcelable(VersionedParcelable versionedParcelable, int i7) {
        setOutputField(i7);
        writeVersionedParcelable(versionedParcelable);
    }
}
