package com.google.common.base;

import java.io.Serializable;
import java.util.Iterator;
import m0.b;
import p0.a;
import p0.f;

@b
public abstract class Converter<A, B> implements Function<A, B> {
    private final boolean handleNullAutomatically;
    @q0.b
    private transient Converter<B, A> reverse;

    /* access modifiers changed from: private */
    public static final class ConverterComposition<A, B, C> extends Converter<A, C> implements Serializable {
        private static final long serialVersionUID = 0;
        final Converter<A, B> first;
        final Converter<B, C> second;

        ConverterComposition(Converter<A, B> converter, Converter<B, C> converter2) {
            this.first = converter;
            this.second = converter2;
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.base.Converter
        public A correctedDoBackward(C c7) {
            return this.first.correctedDoBackward(this.second.correctedDoBackward(c7));
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.base.Converter
        public C correctedDoForward(A a8) {
            return this.second.correctedDoForward(this.first.correctedDoForward(a8));
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public A doBackward(C c7) {
            throw new AssertionError();
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public C doForward(A a8) {
            throw new AssertionError();
        }

        @Override // com.google.common.base.Function, com.google.common.base.Converter
        public boolean equals(Object obj) {
            if (!(obj instanceof ConverterComposition)) {
                return false;
            }
            ConverterComposition converterComposition = (ConverterComposition) obj;
            return this.first.equals(converterComposition.first) && this.second.equals(converterComposition.second);
        }

        public int hashCode() {
            return (this.first.hashCode() * 31) + this.second.hashCode();
        }

        public String toString() {
            return this.first + ".andThen(" + this.second + ")";
        }
    }

    private static final class FunctionBasedConverter<A, B> extends Converter<A, B> implements Serializable {
        private final Function<? super B, ? extends A> backwardFunction;
        private final Function<? super A, ? extends B> forwardFunction;

        private FunctionBasedConverter(Function<? super A, ? extends B> function, Function<? super B, ? extends A> function2) {
            this.forwardFunction = (Function) Preconditions.checkNotNull(function);
            this.backwardFunction = (Function) Preconditions.checkNotNull(function2);
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public A doBackward(B b7) {
            return (A) this.backwardFunction.apply(b7);
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public B doForward(A a8) {
            return (B) this.forwardFunction.apply(a8);
        }

        @Override // com.google.common.base.Function, com.google.common.base.Converter
        public boolean equals(Object obj) {
            if (!(obj instanceof FunctionBasedConverter)) {
                return false;
            }
            FunctionBasedConverter functionBasedConverter = (FunctionBasedConverter) obj;
            return this.forwardFunction.equals(functionBasedConverter.forwardFunction) && this.backwardFunction.equals(functionBasedConverter.backwardFunction);
        }

        public int hashCode() {
            return (this.forwardFunction.hashCode() * 31) + this.backwardFunction.hashCode();
        }

        public String toString() {
            return "Converter.from(" + this.forwardFunction + ", " + this.backwardFunction + ")";
        }
    }

    private static final class IdentityConverter<T> extends Converter<T, T> implements Serializable {
        static final IdentityConverter INSTANCE = new IdentityConverter();
        private static final long serialVersionUID = 0;

        private IdentityConverter() {
        }

        private Object readResolve() {
            return INSTANCE;
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.base.Converter
        public <S> Converter<T, S> doAndThen(Converter<T, S> converter) {
            return (Converter) Preconditions.checkNotNull(converter, "otherConverter");
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public T doBackward(T t7) {
            return t7;
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public T doForward(T t7) {
            return t7;
        }

        @Override // com.google.common.base.Converter
        public IdentityConverter<T> reverse() {
            return this;
        }

        public String toString() {
            return "Converter.identity()";
        }
    }

    private static final class ReverseConverter<A, B> extends Converter<B, A> implements Serializable {
        private static final long serialVersionUID = 0;
        final Converter<A, B> original;

        ReverseConverter(Converter<A, B> converter) {
            this.original = converter;
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.base.Converter
        public B correctedDoBackward(A a8) {
            return this.original.correctedDoForward(a8);
        }

        /* access modifiers changed from: package-private */
        @Override // com.google.common.base.Converter
        public A correctedDoForward(B b7) {
            return this.original.correctedDoBackward(b7);
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public B doBackward(A a8) {
            throw new AssertionError();
        }

        /* access modifiers changed from: protected */
        @Override // com.google.common.base.Converter
        public A doForward(B b7) {
            throw new AssertionError();
        }

        @Override // com.google.common.base.Function, com.google.common.base.Converter
        public boolean equals(Object obj) {
            if (obj instanceof ReverseConverter) {
                return this.original.equals(((ReverseConverter) obj).original);
            }
            return false;
        }

        public int hashCode() {
            return ~this.original.hashCode();
        }

        @Override // com.google.common.base.Converter
        public Converter<A, B> reverse() {
            return this.original;
        }

        public String toString() {
            return this.original + ".reverse()";
        }
    }

    protected Converter() {
        this(true);
    }

    public static <A, B> Converter<A, B> from(Function<? super A, ? extends B> function, Function<? super B, ? extends A> function2) {
        return new FunctionBasedConverter(function, function2);
    }

    public static <T> Converter<T, T> identity() {
        return IdentityConverter.INSTANCE;
    }

    public final <C> Converter<A, C> andThen(Converter<B, C> converter) {
        return doAndThen(converter);
    }

    @Override // com.google.common.base.Function, java.util.function.Function
    @a
    @Deprecated
    public final B apply(A a8) {
        return convert(a8);
    }

    @a
    public final B convert(A a8) {
        return correctedDoForward(a8);
    }

    @a
    public Iterable<B> convertAll(final Iterable<? extends A> iterable) {
        Preconditions.checkNotNull(iterable, "fromIterable");
        return new Iterable<B>() {
            /* class com.google.common.base.Converter.AnonymousClass1 */

            @Override // java.lang.Iterable
            public Iterator<B> iterator() {
                return new Iterator<B>() {
                    /* class com.google.common.base.Converter.AnonymousClass1.AnonymousClass1 */
                    private final Iterator<? extends A> fromIterator;

                    {
                        this.fromIterator = iterable.iterator();
                    }

                    public boolean hasNext() {
                        return this.fromIterator.hasNext();
                    }

                    /* JADX DEBUG: Multi-variable search result rejected for r0v1, resolved type: com.google.common.base.Converter */
                    /* JADX WARN: Multi-variable type inference failed */
                    @Override // java.util.Iterator
                    public B next() {
                        return (B) Converter.this.convert(this.fromIterator.next());
                    }

                    public void remove() {
                        this.fromIterator.remove();
                    }
                };
            }
        };
    }

    /* access modifiers changed from: package-private */
    public A correctedDoBackward(B b7) {
        if (!this.handleNullAutomatically) {
            return doBackward(b7);
        }
        if (b7 == null) {
            return null;
        }
        return (A) Preconditions.checkNotNull(doBackward(b7));
    }

    /* access modifiers changed from: package-private */
    public B correctedDoForward(A a8) {
        if (!this.handleNullAutomatically) {
            return doForward(a8);
        }
        if (a8 == null) {
            return null;
        }
        return (B) Preconditions.checkNotNull(doForward(a8));
    }

    /* access modifiers changed from: package-private */
    public <C> Converter<A, C> doAndThen(Converter<B, C> converter) {
        return new ConverterComposition(this, (Converter) Preconditions.checkNotNull(converter));
    }

    /* access modifiers changed from: protected */
    @f
    public abstract A doBackward(B b7);

    /* access modifiers changed from: protected */
    @f
    public abstract B doForward(A a8);

    @Override // com.google.common.base.Function
    public boolean equals(Object obj) {
        return super.equals(obj);
    }

    @a
    public Converter<B, A> reverse() {
        Converter<B, A> converter = this.reverse;
        if (converter != null) {
            return converter;
        }
        ReverseConverter reverseConverter = new ReverseConverter(this);
        this.reverse = reverseConverter;
        return reverseConverter;
    }

    Converter(boolean z7) {
        this.handleNullAutomatically = z7;
    }
}
