package com.graphisoft.bimx.converter;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Environment;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.util.Log;
import java.net.URLEncoder;
import java.nio.file.FileSystems;
import java.nio.file.Files;
import java.nio.file.LinkOption;
import java.nio.file.Path;
import java.util.Map;
import java.util.TreeMap;
import org.json.JSONArray;
import org.json.JSONObject;

public class FavoriteReader {
    private static final String PREFERENCES_KEY_FAVORITE_PREFIX = "bookmark_";
    private static final String TAG = "FavoriteReader";

    /* access modifiers changed from: private */
    public static class HistoryItem {
        private static final String JSON_KEY_NAME = "name";
        private static final String JSON_KEY_VISIBLE = "visible";
        private static final String JSON_KEY_ZONES_ENABLED = "zonesEnabled";
        private int mIndex = 0;
        private String mName;
        private boolean mVisible = true;
        private boolean mZonesEnabled = false;

        private HistoryItem() {
        }

        public static HistoryItem load(int i7, JSONObject jSONObject) {
            String optString = jSONObject.optString(JSON_KEY_NAME);
            boolean optBoolean = jSONObject.has(JSON_KEY_VISIBLE) ? jSONObject.optBoolean(JSON_KEY_VISIBLE) : true;
            boolean optBoolean2 = jSONObject.has(JSON_KEY_ZONES_ENABLED) ? jSONObject.optBoolean(JSON_KEY_ZONES_ENABLED) : false;
            HistoryItem historyItem = new HistoryItem();
            historyItem.mIndex = i7;
            historyItem.mName = optString;
            historyItem.mVisible = optBoolean;
            historyItem.mZonesEnabled = optBoolean2;
            return historyItem;
        }

        public boolean areZonesEnabled() {
            return this.mZonesEnabled;
        }

        public int getIndex() {
            return this.mIndex;
        }

        public String getName() {
            return this.mName;
        }

        public boolean isVisible() {
            return this.mVisible;
        }
    }

    public static class HistoryItem2D {
        private static final String MGUIDSTRING = "mGUIDStrin";
        private static final String THUMBPATH = "thumbnail";
        private static final String ZOOMRECT = "zoomrect";
        private HistoryItem mBaseInfo;
        private String mTargetPubItemID;
        private float[] mTargetZoomBox;
        private byte[] mThumbnailImage;

        public static HistoryItem2D load(Context context, int i7, JSONObject jSONObject) {
            try {
                HistoryItem2D historyItem2D = new HistoryItem2D();
                historyItem2D.mBaseInfo = HistoryItem.load(i7, jSONObject);
                String string = jSONObject.getString(MGUIDSTRING);
                historyItem2D.mTargetPubItemID = string;
                if (!TextUtils.isEmpty(string) && historyItem2D.mTargetPubItemID.length() > 36) {
                    historyItem2D.mTargetPubItemID = historyItem2D.mTargetPubItemID.substring(0, 36);
                }
                JSONArray optJSONArray = jSONObject.optJSONArray(ZOOMRECT);
                if (optJSONArray != null) {
                    historyItem2D.mTargetZoomBox = new float[4];
                    for (int i8 = 0; i8 < 4; i8++) {
                        historyItem2D.mTargetZoomBox[i8] = (float) optJSONArray.getDouble(i8);
                    }
                }
                String optString = jSONObject.optString(THUMBPATH);
                if (!TextUtils.isEmpty(optString)) {
                    Path path = FileSystems.getDefault().getPath(FavoriteReader.convertOldDocumentPathToNew(context, optString), new String[0]);
                    if (Files.exists(path, new LinkOption[0])) {
                        historyItem2D.mThumbnailImage = Files.readAllBytes(path);
                    }
                }
                return historyItem2D;
            } catch (Throwable th) {
                th.printStackTrace();
                return null;
            }
        }

        public boolean areZonesEnabled() {
            return this.mBaseInfo.areZonesEnabled();
        }

        public int getIndex() {
            return this.mBaseInfo.getIndex();
        }

        public String getName() {
            return this.mBaseInfo.getName();
        }

        public String getTargetPubItemID() {
            return this.mTargetPubItemID;
        }

        public float[] getTargetZoomBox() {
            return this.mTargetZoomBox;
        }

        public byte[] getThumbnailImage() {
            return this.mThumbnailImage;
        }

        public boolean isVisible() {
            return this.mBaseInfo.isVisible();
        }
    }

    public static class HistoryItem3D {
        public static final String CUTENABLED = "cutEnabled";
        public static final String CUTPLANE = "cutPlane";
        public static final String DIRECTION = "direction";
        public static final String MGUIDSTRING = "mGUIDString";
        public static final String PARTIALCUT = "partialCut";
        public static final String POSITION = "position";
        public static final String PREVIEWPATH = "previewPath";
        public static final String RENDERMODE = "RenderMode";
        private HistoryItem mBaseInfo;
        private float[] mCameraDirection;
        private float[] mCameraPosition;
        private float[] mCutPlane;
        private boolean mIsCutEnabled = false;
        private boolean mIsPartialCut = false;
        private byte[] mPreviewImage;
        private int mRenderMode = 0;
        private String mTargetPubItemID;

        public static HistoryItem3D load(Context context, int i7, JSONObject jSONObject) {
            JSONArray optJSONArray;
            try {
                HistoryItem3D historyItem3D = new HistoryItem3D();
                historyItem3D.mBaseInfo = HistoryItem.load(i7, jSONObject);
                String string = jSONObject.getString(MGUIDSTRING);
                historyItem3D.mTargetPubItemID = string;
                if (!TextUtils.isEmpty(string) && historyItem3D.mTargetPubItemID.length() > 36) {
                    historyItem3D.mTargetPubItemID = historyItem3D.mTargetPubItemID.substring(0, 36);
                }
                String optString = jSONObject.optString(PREVIEWPATH);
                if (!TextUtils.isEmpty(optString)) {
                    Path path = FileSystems.getDefault().getPath(FavoriteReader.convertOldDocumentPathToNew(context, optString), new String[0]);
                    if (Files.exists(path, new LinkOption[0])) {
                        historyItem3D.mPreviewImage = Files.readAllBytes(path);
                    }
                }
                JSONArray optJSONArray2 = jSONObject.optJSONArray(POSITION);
                if (optJSONArray2 != null) {
                    historyItem3D.mCameraPosition = new float[3];
                    for (int i8 = 0; i8 < 3; i8++) {
                        historyItem3D.mCameraPosition[i8] = (float) optJSONArray2.getDouble(i8);
                    }
                }
                JSONArray optJSONArray3 = jSONObject.optJSONArray(DIRECTION);
                if (optJSONArray3 != null) {
                    historyItem3D.mCameraDirection = new float[3];
                    for (int i9 = 0; i9 < 3; i9++) {
                        historyItem3D.mCameraDirection[i9] = (float) optJSONArray3.getDouble(i9);
                    }
                }
                historyItem3D.mIsPartialCut = jSONObject.getBoolean(PARTIALCUT);
                boolean z7 = jSONObject.getBoolean(CUTENABLED);
                historyItem3D.mIsCutEnabled = z7;
                if (z7 && (optJSONArray = jSONObject.optJSONArray(CUTPLANE)) != null) {
                    historyItem3D.mCutPlane = new float[4];
                    for (int i10 = 0; i10 < 4; i10++) {
                        historyItem3D.mCutPlane[i10] = (float) optJSONArray.getDouble(i10);
                    }
                }
                historyItem3D.mRenderMode = jSONObject.getInt(RENDERMODE);
                return historyItem3D;
            } catch (Throwable th) {
                th.printStackTrace();
                return null;
            }
        }

        public boolean areZonesEnabled() {
            return this.mBaseInfo.areZonesEnabled();
        }

        public float[] getCameraDirection() {
            return this.mCameraDirection;
        }

        public float[] getCameraPosition() {
            return this.mCameraPosition;
        }

        public float[] getCutPlane() {
            return this.mCutPlane;
        }

        public int getIndex() {
            return this.mBaseInfo.getIndex();
        }

        public String getName() {
            return this.mBaseInfo.getName();
        }

        public byte[] getPreviewImage() {
            return this.mPreviewImage;
        }

        public int getRenderMode() {
            return this.mRenderMode;
        }

        public String getTargetPubItemID() {
            return this.mTargetPubItemID;
        }

        public boolean isCutEnabled() {
            return this.mIsCutEnabled;
        }

        public boolean isPartialCut() {
            return this.mIsPartialCut;
        }

        public boolean isVisible() {
            return this.mBaseInfo.isVisible();
        }
    }

    private static String URLEncode(String str) {
        try {
            return URLEncoder.encode(str, "UTF-8");
        } catch (Throwable th) {
            th.printStackTrace();
            return "";
        }
    }

    /* access modifiers changed from: private */
    public static String convertOldDocumentPathToNew(Context context, String str) {
        String str2 = Environment.getExternalStorageDirectory() + "/bimx";
        if (!str.startsWith(str2)) {
            return str;
        }
        return context.getExternalFilesDir(null) + "/documents" + str.substring(str2.length());
    }

    public static float getDisplayAspect(Context context) {
        DisplayMetrics displayMetrics = context.getResources().getDisplayMetrics();
        return ((float) displayMetrics.heightPixels) / ((float) displayMetrics.widthPixels);
    }

    private static SharedPreferences getPreferences(Context context, String str) {
        return context.getSharedPreferences("HyperModel_" + URLEncode(str), 0);
    }

    public static boolean isNecessary(Context context, String str) {
        TreeMap<Integer, Object> load = load(context, str);
        return load != null && load.size() > 0;
    }

    public static TreeMap<Integer, Object> load(Context context, String str) {
        int i7;
        Integer valueOf;
        Object load;
        try {
            TreeMap<Integer, Object> treeMap = new TreeMap<>();
            for (Map.Entry entry : new TreeMap(getPreferences(context, str).getAll()).entrySet()) {
                String str2 = (String) entry.getKey();
                JSONObject jSONObject = new JSONObject(String.valueOf(entry.getValue()));
                if (str2.startsWith(PREFERENCES_KEY_FAVORITE_PREFIX) && jSONObject.has("Type")) {
                    try {
                        i7 = Integer.parseInt(str2.substring(9));
                    } catch (NumberFormatException unused) {
                        Log.e(TAG, "Invalid favorite key: " + str2);
                        i7 = -1;
                    }
                    int i8 = jSONObject.getInt("Type");
                    if (i8 == 1) {
                        valueOf = Integer.valueOf(i7);
                        load = HistoryItem2D.load(context, i7, jSONObject);
                    } else if (i8 == 2) {
                        valueOf = Integer.valueOf(i7);
                        load = HistoryItem3D.load(context, i7, jSONObject);
                    }
                    treeMap.put(valueOf, load);
                }
            }
            return treeMap;
        } catch (Throwable th) {
            th.printStackTrace();
            return null;
        }
    }
}
