package com.google.cardboard.sdk.qrcode;

import android.content.Context;
import android.net.Uri;
import android.util.Base64;
import android.util.Log;
import androidx.annotation.Nullable;
import com.google.cardboard.sdk.deviceparams.CardboardV1DeviceParams;
import com.google.common.net.c;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.ProtocolException;
import java.nio.ByteBuffer;

public abstract class CardboardParamsUtils {
    private static final String CARDBOARD_CONFIG_FOLDER = "Cardboard";
    private static final String CARDBOARD_DEVICE_PARAMS_FILE = "current_device_params";
    private static final int CARDBOARD_DEVICE_PARAMS_STREAM_SENTINEL = 894990891;
    private static final String HTTPS_SCHEME = "https";
    private static final String HTTPS_SCHEME_PREFIX = "https://";
    private static final int HTTPS_TIMEOUT_MS = 5000;
    private static final String HTTP_SCHEME = "http";
    private static final String HTTP_SCHEME_PREFIX = "http://";
    private static final int MAX_REDIRECTS = 5;
    private static final String TAG = "CardboardParamsUtils";
    private static final int URI_CODING_PARAMS = 11;
    private static final String URI_HOST_GOOGLE = "google.com";
    private static final String URI_HOST_GOOGLE_SHORT = "g.co";
    private static final String URI_KEY_PARAMS = "p";
    private static final Uri URI_ORIGINAL_CARDBOARD_QR_CODE = new Uri.Builder().scheme(HTTPS_SCHEME).authority(URI_HOST_GOOGLE_SHORT).appendEncodedPath(URI_PATH_CARDBOARD_HOME).build();
    private static final String URI_PATH_CARDBOARD_CONFIG = "cardboard/cfg";
    private static final String URI_PATH_CARDBOARD_HOME = "cardboard";

    public static class UriToParamsStatus {
        public static final int STATUS_CONNECTION_ERROR = 2;
        public static final int STATUS_OK = 0;
        public static final int STATUS_UNEXPECTED_FORMAT = 1;
        @Nullable
        public final byte[] params;
        public final int statusCode;

        private UriToParamsStatus(int i7, @Nullable byte[] bArr) {
            this.statusCode = i7;
            this.params = bArr;
        }

        public static UriToParamsStatus error(int i7) {
            return new UriToParamsStatus(i7, null);
        }

        public static UriToParamsStatus success(byte[] bArr) {
            return new UriToParamsStatus(0, bArr);
        }
    }

    public static byte[] createFromUri(Uri uri) {
        if (uri == null) {
            return null;
        }
        if (isOriginalCardboardDeviceUri(uri)) {
            return CardboardV1DeviceParams.build().toByteArray();
        }
        if (isCardboardDeviceUri(uri)) {
            return readDeviceParamsFromUri(uri);
        }
        Log.w(TAG, String.format("URI \"%s\" not recognized as Cardboard viewer.", uri));
        return null;
    }

    @Nullable
    private static Uri followCardboardParamRedirect(Uri uri, int i7, UrlFactory urlFactory) throws IOException {
        int i8 = 0;
        while (uri != null && !isCardboardUri(uri)) {
            if (i8 >= i7) {
                String str = TAG;
                Log.d(str, "Exceeding the number of maximum redirects: " + i7);
                return null;
            }
            uri = resolveHttpsRedirect(uri, urlFactory);
            i8++;
        }
        return uri;
    }

    private static File getDeviceParamsFile(Context context) {
        File file = new File(context.getFilesDir(), CARDBOARD_CONFIG_FOLDER);
        if (!file.exists()) {
            file.mkdirs();
        } else if (!file.isDirectory()) {
            throw new IllegalStateException(file + " already exists as a file, but is expected to be a directory.");
        }
        return new File(file, CARDBOARD_DEVICE_PARAMS_FILE);
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0072  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x007c  */
    public static UriToParamsStatus getParamsFromUriString(String str, UrlFactory urlFactory) {
        Uri followCardboardParamRedirect;
        String replaceFirst;
        Uri parse = Uri.parse(str);
        if (parse == null) {
            Log.e(TAG, "Error when parsing URI: " + parse);
            return UriToParamsStatus.error(1);
        }
        if (parse.getScheme() == null) {
            replaceFirst = HTTPS_SCHEME_PREFIX + parse;
        } else {
            if (parse.getScheme().equals(HTTP_SCHEME)) {
                replaceFirst = parse.toString().replaceFirst(HTTP_SCHEME_PREFIX, HTTPS_SCHEME_PREFIX);
            }
            String str2 = TAG;
            Log.d(str2, "Following redirects for original URI: " + parse);
            followCardboardParamRedirect = followCardboardParamRedirect(parse, 5, urlFactory);
            if (followCardboardParamRedirect != null) {
                Log.e(str2, "Error when following URI redirects");
                return UriToParamsStatus.error(1);
            }
            byte[] createFromUri = createFromUri(followCardboardParamRedirect);
            if (createFromUri != null) {
                return UriToParamsStatus.success(createFromUri);
            }
            Log.e(str2, "Error when parsing device parameters from URI query string: " + followCardboardParamRedirect);
            return UriToParamsStatus.error(1);
        }
        parse = Uri.parse(replaceFirst);
        try {
            String str22 = TAG;
            Log.d(str22, "Following redirects for original URI: " + parse);
            followCardboardParamRedirect = followCardboardParamRedirect(parse, 5, urlFactory);
            if (followCardboardParamRedirect != null) {
            }
        } catch (IOException e7) {
            Log.w(TAG, "Error while following URL redirect " + e7);
            return UriToParamsStatus.error(2);
        }
    }

    private static boolean isCardboardDeviceUri(Uri uri) {
        return HTTPS_SCHEME.equals(uri.getScheme()) && URI_HOST_GOOGLE.equals(uri.getAuthority()) && "/cardboard/cfg".equals(uri.getPath());
    }

    public static boolean isCardboardUri(Uri uri) {
        return isOriginalCardboardDeviceUri(uri) || isCardboardDeviceUri(uri);
    }

    private static boolean isOriginalCardboardDeviceUri(Uri uri) {
        return URI_ORIGINAL_CARDBOARD_QR_CODE.equals(uri);
    }

    public static byte[] readDeviceParams(Context context) {
        return readDeviceParamsFromStorage(context);
    }

    private static byte[] readDeviceParamsFromInputStream(InputStream inputStream) {
        if (inputStream == null) {
            return null;
        }
        try {
            ByteBuffer allocate = ByteBuffer.allocate(8);
            if (inputStream.read(allocate.array(), 0, allocate.array().length) == -1) {
                Log.e(TAG, "Error parsing param record: end of stream.");
                return null;
            }
            int i7 = allocate.getInt();
            int i8 = allocate.getInt();
            if (i7 != CARDBOARD_DEVICE_PARAMS_STREAM_SENTINEL) {
                Log.e(TAG, "Error parsing param record: incorrect sentinel.");
                return null;
            }
            byte[] bArr = new byte[i8];
            if (inputStream.read(bArr, 0, i8) != -1) {
                return bArr;
            }
            Log.e(TAG, "Error parsing param record: end of stream.");
            return null;
        } catch (IOException e7) {
            String str = TAG;
            Log.w(str, "Error reading parameters: " + e7);
            return null;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x001d, code lost:
        r4 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x001e, code lost:
        android.util.Log.w(com.google.cardboard.sdk.qrcode.CardboardParamsUtils.TAG, "Error reading parameters: " + r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0035, code lost:
        r4 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0036, code lost:
        android.util.Log.d(com.google.cardboard.sdk.qrcode.CardboardParamsUtils.TAG, "Parameters file not found for reading: " + r4);
     */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [B:6:0x000f, B:14:0x001c] */
    /* JADX WARNING: Missing exception handler attribute for start block: B:14:0x001c */
    /* JADX WARNING: Removed duplicated region for block: B:12:0x0019 A[SYNTHETIC, Splitter:B:12:0x0019] */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x001d A[ExcHandler: IllegalStateException (r4v1 'e' java.lang.IllegalStateException A[CUSTOM_DECLARE]), Splitter:B:6:0x000f] */
    private static byte[] readDeviceParamsFromStorage(Context context) {
        InputStream inputStream;
        Throwable th;
        byte[] bArr = null;
        try {
            inputStream = InputStreamProvider.get(getDeviceParamsFile(context));
            try {
                bArr = readDeviceParamsFromInputStream(inputStream);
                if (inputStream != null) {
                    try {
                        inputStream.close();
                    } catch (IOException unused) {
                    } catch (IllegalStateException e7) {
                    }
                }
                return bArr;
            } catch (Throwable th2) {
                th = th2;
                if (inputStream != null) {
                    inputStream.close();
                }
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            inputStream = null;
            if (inputStream != null) {
            }
            throw th;
        }
    }

    private static byte[] readDeviceParamsFromUri(Uri uri) {
        String queryParameter = uri.getQueryParameter(URI_KEY_PARAMS);
        if (queryParameter == null) {
            Log.w(TAG, "No Cardboard parameters in URI.");
            return null;
        }
        try {
            return Base64.decode(queryParameter, 11);
        } catch (Exception e7) {
            String str = TAG;
            Log.w(str, "Parsing Cardboard parameters from URI failed: " + e7);
            return null;
        }
    }

    @Nullable
    private static Uri resolveHttpsRedirect(Uri uri, UrlFactory urlFactory) throws IOException {
        HttpURLConnection openHttpsConnection = urlFactory.openHttpsConnection(uri);
        if (openHttpsConnection == null) {
            return null;
        }
        openHttpsConnection.setInstanceFollowRedirects(false);
        openHttpsConnection.setDoInput(false);
        openHttpsConnection.setConnectTimeout(HTTPS_TIMEOUT_MS);
        openHttpsConnection.setReadTimeout(HTTPS_TIMEOUT_MS);
        openHttpsConnection.setRequestProperty(c.f11604j, "");
        try {
            openHttpsConnection.setRequestMethod("HEAD");
            try {
                openHttpsConnection.connect();
                int responseCode = openHttpsConnection.getResponseCode();
                String str = TAG;
                Log.i(str, "Response code: " + responseCode);
                if (responseCode != 301 && responseCode != 302) {
                    return null;
                }
                String headerField = openHttpsConnection.getHeaderField(c.f11617n0);
                if (headerField == null) {
                    Log.d(str, "Returning null because of null location.");
                    openHttpsConnection.disconnect();
                    return null;
                }
                Log.i(str, "Location: " + headerField);
                Uri parse = Uri.parse(headerField.replaceFirst(HTTP_SCHEME_PREFIX, HTTPS_SCHEME_PREFIX));
                if (parse == null || parse.compareTo(uri) == 0) {
                    Log.d(str, "Returning null because of wrong redirect URI.");
                    openHttpsConnection.disconnect();
                    return null;
                }
                Log.i(str, "Param URI redirect to " + parse);
                openHttpsConnection.disconnect();
                return parse;
            } finally {
                openHttpsConnection.disconnect();
            }
        } catch (ProtocolException e7) {
            Log.w(TAG, e7.toString());
            return null;
        }
    }

    public static void saveCardboardV1DeviceParams(Context context) {
        if (!writeDeviceParamsToStorage(CardboardV1DeviceParams.build().toByteArray(), context)) {
            Log.e(TAG, "Could not write Cardboard parameters to storage.");
        }
    }

    public static void saveParamsFromUri(byte[] bArr, Context context) {
        String str = new String(bArr);
        UriToParamsStatus paramsFromUriString = getParamsFromUriString(str, new UrlFactory());
        if (paramsFromUriString.statusCode != 0) {
            String str2 = TAG;
            Log.e(str2, "Error when trying to get the Cardboard params from URI: " + str);
            return;
        }
        boolean writeDeviceParams = writeDeviceParams(paramsFromUriString.params, context);
        String str3 = TAG;
        StringBuilder sb = new StringBuilder();
        sb.append("Could ");
        sb.append(!writeDeviceParams ? "not " : "");
        sb.append("write Cardboard parameters to storage.");
        Log.d(str3, sb.toString());
    }

    public static boolean writeDeviceParams(byte[] bArr, Context context) {
        return writeDeviceParamsToStorage(bArr, context);
    }

    private static boolean writeDeviceParamsToOutputStream(byte[] bArr, OutputStream outputStream) {
        try {
            ByteBuffer allocate = ByteBuffer.allocate(8);
            allocate.putInt(CARDBOARD_DEVICE_PARAMS_STREAM_SENTINEL);
            allocate.putInt(bArr.length);
            outputStream.write(allocate.array());
            outputStream.write(bArr);
            return true;
        } catch (IOException e7) {
            String str = TAG;
            Log.w(str, "Error writing parameters: " + e7);
            return false;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x002c, code lost:
        if (r0 == null) goto L_0x004c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:?, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0049, code lost:
        if (r0 == null) goto L_0x004c;
     */
    private static boolean writeDeviceParamsToStorage(byte[] bArr, Context context) {
        OutputStream outputStream = null;
        try {
            outputStream = OutputStreamProvider.get(getDeviceParamsFile(context));
            boolean writeDeviceParamsToOutputStream = writeDeviceParamsToOutputStream(bArr, outputStream);
            if (outputStream == null) {
                return writeDeviceParamsToOutputStream;
            }
            try {
                outputStream.close();
                return writeDeviceParamsToOutputStream;
            } catch (IOException unused) {
                return writeDeviceParamsToOutputStream;
            }
        } catch (FileNotFoundException e7) {
            String str = TAG;
            Log.e(str, "Parameters file not found for writing: " + e7);
        } catch (IllegalStateException e8) {
            String str2 = TAG;
            Log.w(str2, "Error writing parameters: " + e8);
        } catch (Throwable th) {
            if (outputStream != null) {
                try {
                    outputStream.close();
                } catch (IOException unused2) {
                }
            }
            throw th;
        }
        return false;
    }
}
